@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   7/8/04
 *
-* $Revision: 1.15 $
+* $Revision: 1.19 $
 *
 * File Description: 
 *
@@ -137,24 +137,61 @@ NLM_EXTERN void Taxon3ReplaceOrgInSeqEntry (SeqEntryPtr sep, Boolean keep_syn);
 NLM_EXTERN void Taxon3CheckOrgInSeqEntry (SeqEntryPtr sep, ValNodePtr PNTR not_found, ValNodePtr PNTR bad_match);
 NLM_EXTERN void CheckTaxNamesAgainstTaxDatabase (ValNodePtr PNTR discrepancy_list, ValNodePtr sep_list);
 
-NLM_EXTERN Boolean IsOrgModSpecificHostToBeChecked (OrgModPtr mod, Boolean for_validator);
-NLM_EXTERN ValNodePtr Taxon3CheckSpecificHostInSeqEntry (SeqEntryPtr sep, Boolean for_validator);
-NLM_EXTERN Boolean Taxon3FixSpecificHostInSeqEntry (SeqEntryPtr sep);
+typedef enum {
+  eReturnedOrgFlag_normal = 3,
+  eReturnedOrgFlag_misspelled = 4,
+  eReturnedOrgFlag_ambiguous = 5,
+  eReturnedOrgFlag_error
+} EReturnedOrgFlag;
+
+typedef enum {
+  eSpecificHostFix_unrecognized = 0,
+  eSpecificHostFix_spelling,
+  eSpecificHostFix_capitalization,
+  eSpecificHostFix_truncation,
+  eSpecificHostFix_replacement,
+  eSpecificHostFix_ambiguous
+} ESpecificHostFix;
+
+NLM_EXTERN void 
+Taxon3ValidateSpecificHostsInSeqEntry 
+(SeqEntryPtr sep,
+ ValNodePtr PNTR misspelled_list,
+ ValNodePtr PNTR bad_caps_list,
+ ValNodePtr PNTR ambiguous_list,
+ ValNodePtr PNTR unrecognized_list);
 
 typedef struct specifichostfix {
   ValNodePtr feat_or_desc;
   CharPtr    bad_specific_host;
   CharPtr    old_taxname;
   CharPtr    new_taxname;
+  Uint1      fix_type;
 } SpecificHostFixData, PNTR SpecificHostFixPtr;
 
 extern ValNodePtr SpecificHostFixListFree (ValNodePtr vnp);
 extern Boolean ApplyOneSpecificHostFix (SpecificHostFixPtr s);
 /* returns ValNodePtr list of SpecificHostFixPtr */
-NLM_EXTERN ValNodePtr Taxon3GetSpecificHostFixesInSeqEntry (SeqEntryPtr sep);
+NLM_EXTERN ValNodePtr Taxon3GetSpecificHostFixesInSeqEntry (SeqEntryPtr sep, Boolean caps, Boolean paren);
 
 NLM_EXTERN ValNodePtr GetOrganismTaxLookupFailuresInSeqEntry (SeqEntryPtr sep);
 
+typedef struct taxfixitem {
+  Uint1 data_choice;
+  Pointer data;
+  OrgRefPtr response_org;
+  CharPtr taxname;
+  CharPtr suggested_fix;
+  CharPtr rank;
+} TaxFixItemData, PNTR TaxFixItemPtr;
+
+NLM_EXTERN TaxFixItemPtr TaxFixItemNew (void);
+NLM_EXTERN TaxFixItemPtr TaxFixItemCopy (TaxFixItemPtr orig);
+NLM_EXTERN TaxFixItemPtr TaxFixItemFree (TaxFixItemPtr t);
+NLM_EXTERN ValNodePtr LIBCALLBACK TaxFixItemListFree (ValNodePtr vnp);
+NLM_EXTERN ValNodePtr Taxon3GetTaxFixList (ValNodePtr biop_list);
+
+
 
 #ifdef __cplusplus
 }
