@@ -1,4 +1,4 @@
-/* $Id: blast_nascan.h,v 1.5 2008/07/23 16:55:47 kazimird Exp $
+/* $Id: blast_nascan.h,v 1.6 2009/05/27 17:39:36 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -54,6 +54,13 @@ typedef Int4 (*TNaScanSubjectFunction)(const LookupTableWrap* lookup_wrap,
 NCBI_XBLAST_EXPORT
 void BlastChooseNucleotideScanSubject(LookupTableWrap *lookup_wrap);
 
+/** Return the most generic function to scan through
+ * nucleotide subject sequences
+ * @param lookup_wrap Structure containing lookup table [in][out]
+ */
+NCBI_XBLAST_EXPORT
+void * BlastChooseNucleotideScanSubjectAny(LookupTableWrap *lookup_wrap);
+
 #ifdef __cplusplus
 }
 #endif
