@@ -1,6 +1,6 @@
 #ifndef SKIP_DOXYGEN_PROCESSING
 static char const rcsid[] =
-    "$Id: blast_psi.c,v 1.36 2008/04/15 15:55:45 kazimird Exp $";
+    "$Id: blast_psi.c,v 1.37 2009/05/27 17:39:36 kazimird Exp $";
 #endif /* SKIP_DOXYGEN_PROCESSING */
 /* ===========================================================================
  *
@@ -156,7 +156,7 @@ PSICreatePssmWithDiagnostics(const PSIMsa* msap,                    /* [in] */
         _PSIStructureGroupCustomization(msa);
         status = _PSIValidateMSA_StructureGroup(msa);
     } else {
-        status = _PSIValidateMSA(msa);
+        status = _PSIValidateMSA(msa, options->ignore_unaligned_positions);
     }
     if (status != PSI_SUCCESS) {
         s_PSICreatePssmCleanUp(pssm, packed_msa, msa, aligned_block, 
@@ -495,6 +495,26 @@ PSIDiagnosticsRequestNew(void)
     return calloc(1, sizeof(PSIDiagnosticsRequest));
 }
 
+PSIDiagnosticsRequest* 
+PSIDiagnosticsRequestNewEx(Boolean save_ascii_pssm)
+{
+    PSIDiagnosticsRequest* retval = PSIDiagnosticsRequestNew(); 
+    if ( !retval ) {
+        return NULL;
+    }
+
+    retval->frequency_ratios = TRUE;
+    if (save_ascii_pssm) {
+        retval->information_content = TRUE;
+        retval->weighted_residue_frequencies = TRUE;
+        retval->gapless_column_weights = TRUE;
+        retval->sigma = TRUE;
+        retval->interval_sizes = TRUE;
+        retval->num_matching_seqs = TRUE;
+    }
+    return retval;
+}
+
 PSIDiagnosticsRequest* 
 PSIDiagnosticsRequestFree(PSIDiagnosticsRequest* diags_request)
 {
