@@ -1,4 +1,4 @@
-/*  $Id: blast_stat.h,v 1.78 2006/04/20 19:26:37 madden Exp $
+/*  $Id: blast_stat.h,v 1.88 2008/11/03 20:59:44 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -32,12 +32,15 @@
  * statistics. @todo FIXME: needs doxygen comments
  */
 
-#ifndef __BLAST_STAT__
-#define __BLAST_STAT__
+#ifndef ALGO_BLAST_CORE__BLAST_STAT__H
+#define ALGO_BLAST_CORE__BLAST_STAT__H
 
-#include <algo/blast/core/blast_def.h>
+#include <algo/blast/core/ncbi_std.h>
+#include <algo/blast/core/blast_export.h>
+#include <algo/blast/core/blast_program.h>
 #include <algo/blast/core/blast_query_info.h>
 #include <algo/blast/core/blast_message.h>
+#include <util/tables/raw_scoremat.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -54,6 +57,9 @@ extern "C" {
 
 #define BLASTMAT_DIR "/usr/ncbi/blast/matrix" /**< Default location for blast databases. */
 
+/** callback to resolve the path to blast score matrices */
+typedef char* (*GET_MATRIX_PATH) (const char*, Boolean);
+
 /**
   Structure to hold the Karlin-Altschul parameters.
 */
@@ -166,6 +172,34 @@ protein alphabet (e.g., ncbistdaa etc.), FALSE for nt. alphabets. */
    Boolean  round_down; /**< Score must be rounded down to nearest even score if odd. */
 } BlastScoreBlk;
 
+/** Scoring matrix data used for compressed protein alphabets */
+typedef struct SCompressedAlphabet {
+    Int4  compressed_alphabet_size;  /**< letters in the compressed alphabet */
+    SBlastScoreMatrix* matrix;    /**< score matrix */
+    Uint1* compress_table;  /**< translation table (AA->compressed)*/
+} SCompressedAlphabet;
+
+/** Allocate a new compressed alphabet and score matrix
+ * @param sbp Current score matrix information [in]
+ * @param compressed_alphabet_size Desired size of compressed
+ *                  alphabet (current choices are limited to 10 or 15) [in]
+ * @param scale_factor Score matrix entries are scaled by this value [in]
+ * @return the new alphabet, or NULL on failure
+ */
+NCBI_XBLAST_EXPORT
+SCompressedAlphabet*
+SCompressedAlphabetNew(BlastScoreBlk *sbp,
+                       Int4 compressed_alphabet_size, 
+                       double scale_factor);
+
+/** Free a compressed alphabet and score matrix
+ * @param alphabet The compressed alphabet structure
+ * @return Always NULL
+ */
+NCBI_XBLAST_EXPORT
+SCompressedAlphabet*
+SCompressedAlphabetFree(SCompressedAlphabet *alphabet);
+
 /** 
 Stores the letter frequency of a sequence or database.
 */
@@ -226,10 +260,11 @@ Blast_ScoreBlkKbpUngappedCalc(EBlastProgramType program,
  * -read in the matrix
  * -set maxscore
  * @param sbp Scoring block [in] [out]
- * @param matrix Full path to the matrix in the directory structure [in]
+ * @param get_path pointer to function that will return path to matrix.  Only called
+ *  if built-in matrix not found [in]
 */
 NCBI_XBLAST_EXPORT
-Int2 Blast_ScoreBlkMatrixFill (BlastScoreBlk* sbp, char* matrix);
+Int2 Blast_ScoreBlkMatrixFill (BlastScoreBlk* sbp, GET_MATRIX_PATH get_path);
  
 /** Callocs a Blast_KarlinBlk
  * @return pointer to the Blast_KarlinBlk
@@ -259,15 +294,13 @@ Blast_KarlinBlk* Blast_KarlinBlkFree(Blast_KarlinBlk* kbp);
  * @param kbp object to be filled in [in|out]
  * @param gap_open cost of gap existence [in]
  * @param gap_extend cost to extend a gap one letter [in]
- * @param decline_align cost of declining to align a letter [in]
  * @param matrix_name name of the matrix to be used [in]
  * @param error_return filled in with error message if needed [out]
  * @return zero on success
  */
 NCBI_XBLAST_EXPORT
 Int2 Blast_KarlinBlkGappedCalc (Blast_KarlinBlk* kbp, Int4 gap_open, 
-        Int4 gap_extend, Int4 decline_align, const char* matrix_name, 
-        Blast_Message** error_return);
+     Int4 gap_extend, const char* matrix_name, Blast_Message** error_return);
 
 /** Retrieves Karlin-Altschul parameters from precomputed tables, given the
  * substitution and gap scores. Gap cost values greater than any of those 
@@ -309,14 +342,13 @@ Int2 Blast_ScoreBlkKbpIdealCalc(BlastScoreBlk* sbp);
  * @param kbp object to be filled in [in|out]
  * @param gap_open gap existence cost [in]
  * @param gap_extend gap extension cost [in]
- * @param decline_align cost to not align part of a sequence [in]
  * @param matrix_name name of the matrix used [in]
  * @return  -1 if matrix_name is NULL;
  *          1 if matrix not found
  *           2 if matrix found, but open, extend etc. values not supported.
 */
 NCBI_XBLAST_EXPORT
-Int2 Blast_KarlinBlkGappedLoadFromTables(Blast_KarlinBlk* kbp, Int4 gap_open, Int4 gap_extend, Int4 decline_align, const char* matrix_name);
+Int2 Blast_KarlinBlkGappedLoadFromTables(Blast_KarlinBlk* kbp, Int4 gap_open, Int4 gap_extend, const char* matrix_name);
 
 /** Prints a messages about the allowed matrices, BlastKarlinBlkGappedFill should return 1 before this is called. 
  * @param matrix the matrix to print a message about [in]
@@ -330,11 +362,10 @@ char* BLAST_PrintMatrixMessage(const char *matrix);
  * @param matrix name of the matrix [in]
  * @param gap_open gap existence cost [in]
  * @param gap_extend cost to extend a gap by one [in]
- * @param decline_align cost of declining to align [in]
  * @return message
  */
 NCBI_XBLAST_EXPORT
-char* BLAST_PrintAllowedValues(const char *matrix, Int4 gap_open, Int4 gap_extend, Int4 decline_align);
+char* BLAST_PrintAllowedValues(const char *matrix, Int4 gap_open, Int4 gap_extend);
 
 /** Calculates the parameter Lambda given an initial guess for its value */
 NCBI_XBLAST_EXPORT
@@ -351,6 +382,46 @@ Blast_KarlinLambdaNR(Blast_ScoreFreq* sfp, double initialLambdaGuess);
 NCBI_XBLAST_EXPORT
 double BLAST_KarlinStoE_simple (Int4 S, Blast_KarlinBlk* kbp, Int8  searchsp);
 
+/** Convert a P-value to an E-value.
+ *
+ * P-values and E-values may either represent statistics of a database
+ * search or represent statistics on the two sequences being compared.
+ * If given a database P-value, this routine will return a database
+ * E-value; if given a pairwise P-value, it will return a pairwise
+ * E-value.
+ *  
+ * In the context of a database search, the available P-value is often
+ * a pairwise P-value, whereas the desired E-value is a database
+ * E-value.  When this it the case, the value returned by this routine
+ * should be multiplied by the effective length of the database and
+ * divided by the effective length of the subject.
+ * 
+ * @param p the P-value to be converted [in] @return the corresponding
+ * expect value.
+ */
+NCBI_XBLAST_EXPORT double BLAST_KarlinPtoE(double p);
+
+/** Convert an E-value to a P-value.
+ * 
+ * E-values and P-values may either represent statistics of a database
+ * search or represent statistics on the two sequences being compared.
+ * If given a database E-value, this routine will return a database
+ * P-value; if given a pairwise E-value, it will return a pairwise
+ * P-value.
+ *
+ * In the context of a database search, the available E-value is
+ * typically a database E-value, whereas the desired P-value is a
+ * pairwise P-value.  When this is the case, the E-value should be
+ * divided by the effective length of the database and multiplied by
+ * the effective length of the subject, before BLAST_KarlinEtoP is
+ * called.
+ *
+ * @param x the expect value to be converted [in]
+ * @return the corresponding p-value.
+ */
+NCBI_XBLAST_EXPORT
+double BLAST_KarlinEtoP(double x);
+
 /** Compute a divisor used to weight the evalue of a collection of
  * "nsegs" distinct alignments.  These divisors are used to compensate
  * for the effect of choosing the best among multiple collections of
@@ -475,6 +546,15 @@ Int2 BLAST_GetNucleotideGapExistenceExtendParams(Int4 reward,
                                        Int4* gap_existence,
                                        Int4* gap_extension);
 
+/** Check the validity of the reward and penalty scores.
+ * Only to be used with blastn searches.
+ * @param reward match score [in]
+ * @param penalty mismatch score [in]
+ * @return TRUE on success 
+ */
+NCBI_XBLAST_EXPORT
+Boolean BLAST_CheckRewardPenaltyScores(Int4 reward, Int4 penalty);
+
 /** Extract the alpha and beta settings for this matrixName, and these
  *  gap open and gap extension costs
  * @param matrixName name of the matrix used [in]
@@ -523,13 +603,13 @@ Int2 Blast_GetNuclAlphaBeta(Int4 reward, Int4 penalty, Int4 gap_open,
  * @param rps_query_seq the query sequence [in]
  * @param db_seq_length Length of the database sequence [in]
  * @param posMatrix matrix (actual) values to be used [in]
- * @param matrix_name Name of the score matrix underlying the RPS search [in]
+ * @param sbp Structure with score matrix parameters [in][out]
  * @return rescaled pssm 
  */
 NCBI_XBLAST_EXPORT
 Int4 ** RPSRescalePssm(double scalingFactor, Int4 rps_query_length, 
                    const Uint1 * rps_query_seq, Int4 db_seq_length, 
-                   Int4 **posMatrix, const char *matrix_name);
+                   Int4 **posMatrix, BlastScoreBlk *sbp);
 
 
 /** 
@@ -671,7 +751,16 @@ Blast_FillResidueProbability(const Uint1* sequence, Int4 length, double * resPro
 NCBI_XBLAST_EXPORT
 Int2 BlastScoreBlkNuclMatrixCreate(BlastScoreBlk* sbp);
 
+/** Returns a pointer to the static compiled in version of the 
+ * matrix.  If name is NULL or the matrix is not compiled in
+ * NULL is returned.
+ * @param name matrix name [in]
+ * @return pointer to matrix or NULL if not supported.
+ */
+NCBI_XBLAST_EXPORT 
+SNCBIPackedScoreMatrix* BlastScoreBlkGetCompiledInMatrix(const char* name);
+
 #ifdef __cplusplus
 }
 #endif
-#endif /* !__BLAST_STAT__ */
+#endif /* !ALGO_BLAST_CORE__BLAST_STAT__H */
