@@ -1,4 +1,4 @@
-/* $Id: blast_util.h,v 1.78 2006/09/12 20:53:33 camacho Exp $
+/* $Id: blast_util.h,v 1.84 2009/01/07 16:29:41 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -30,9 +30,11 @@
  * Various auxiliary BLAST utility functions
  */
 
-#ifndef __BLAST_UTIL__
-#define __BLAST_UTIL__
+#ifndef ALGO_BLAST_CORE__BLAST_UTIL__H
+#define ALGO_BLAST_CORE__BLAST_UTIL__H
 
+#include <algo/blast/core/ncbi_std.h>
+#include <algo/blast/core/blast_program.h>
 #include <algo/blast/core/blast_def.h>
 #include <algo/blast/core/blast_query_info.h>
 #include <algo/blast/core/blast_encoding.h>
@@ -75,6 +77,7 @@ void BlastSequenceBlkCopy(BLAST_SequenceBlk** copy,
  * @param program string name of program [in]
  * @param number Enumerated value of program [out]
 */
+NCBI_XBLAST_EXPORT
 Int2 BlastProgram2Number(const char *program, EBlastProgramType *number);
 
 /** Return string name for program given a number.  Return is zero on success.
@@ -125,7 +128,36 @@ Int2 BlastSeqBlkSetSequence(BLAST_SequenceBlk* seq_blk,
 NCBI_XBLAST_EXPORT
 Int2 BlastSeqBlkSetCompressedSequence(BLAST_SequenceBlk* seq_blk,
                                       const Uint1* sequence);
+
+/** Sets the seq_range and related fields appropriately in the
+ * BLAST_SequenceBlk structure
+ * @param seq_blk The sequence block structure to modify [in/out]
+ * @param seq_ranges sequence ranges to copy [in]
+ * @param num_seq_ranges number of elements in array above [in]
+ * @param copy_seq_ranges set to TRUE if seq_ranges should be copied to the
+ * BLAST_SequenceBlk and assume its ownership, set to FALSE if the pointer
+ * should be copied and the ownership of the seq_ranges remains in the caller's
+ * possession.
+ * @note this function will free the memory previously allocated to
+ * BLAST_SequenceBlk::seq_ranges (if applicable) and overwrite it with the
+ * seq_ranges argument. This might invalidate BLAST_SequenceBlk structures that
+ * were copied off of this one.
+ */
+NCBI_XBLAST_EXPORT
+Int2 BlastSeqBlkSetSeqRanges(BLAST_SequenceBlk* seq_blk,
+                             SSeqRange* seq_ranges,
+                             Uint4 num_seq_ranges,
+                             Boolean copy_seq_ranges);
                             
+/** Adds a specialized representation of sequence data to a sequence
+ * block. In the specialized representation, the byte at offset i 
+ * packs together nucleotide bases i to i+3
+ * @param seq_blk structure containing sequence data. Data is assumed
+ *          to be in blastna format [in][out]
+ */
+NCBI_XBLAST_EXPORT
+Int2 BlastCompressBlastnaSequence(BLAST_SequenceBlk *seq_blk);
+
 
 /** GetTranslation to get the translation of the nucl. sequence in the
  * appropriate frame and with the appropriate GeneticCode.
@@ -138,7 +170,7 @@ Int2 BlastSeqBlkSetCompressedSequence(BLAST_SequenceBlk* seq_blk,
  * @param buffer Preallocated buffer for the translated sequence [in][out]
  * @param genetic_code Genetic code to use for translation, 
  *                     in ncbistdaa encoding [in]
- * @return Length of the traslated protein sequence.
+ * @return Length of the translated protein sequence.
 */
 NCBI_XBLAST_EXPORT
 Int4 BLAST_GetTranslation(const Uint1* query_seq, 
@@ -221,6 +253,7 @@ Int2 BLAST_PackDNA(const Uint1* buffer, Int4 length,
  * 
  * @return The requested length, or 0 if the nucleotide length is 0
  */
+NCBI_XBLAST_EXPORT
 size_t
 BLAST_GetTranslatedProteinLength(size_t nucleotide_length, 
                                  unsigned int context);
@@ -311,6 +344,7 @@ BLAST_GetStandardAaProbabilities(void);
  * @return newly allocated string in upper case or NULL if string is NULL or
  * out of memory
  */
+NCBI_XBLAST_EXPORT
 char*
 BLAST_StrToUpper(const char* string);
 
@@ -319,6 +353,14 @@ BLAST_StrToUpper(const char* string);
  */
 #define MAX_FULL_TRANSLATION 2100
 
+/** This sentry value is used as a 'fence' around the valid portions
+ * of partially decoded sequences.  If an alignment finds this value
+ * in a subject sequence, the fence_hit flag should be used to request
+ * a refetch of the whole sequence, and the alignment restarted.
+ */
+#define FENCE_SENTRY 201
+
+
 /** Translate the subject sequence into 6 frames, and create a mixed-frame 
  * sequence, if out-of-frame gapping will be used.
  * @param subject_blk Subject sequence structure [in]
@@ -346,7 +388,28 @@ Blast_SetUpSubjectTranslation(BLAST_SequenceBlk* subject_blk,
 NCBI_XBLAST_EXPORT
 unsigned int BLAST_GetNumberOfContexts(EBlastProgramType program);
 
+/** Free SBlastTargetTranslation
+ * @target_t object to be freed [in]
+ */
+NCBI_XBLAST_EXPORT
+SBlastTargetTranslation*
+BlastTargetTranslationFree(SBlastTargetTranslation* target_t);
+
+/** Sets up structure for target translation.
+ * @subject_blk Target sequence information [in]
+ * @gen_code_string Genetic code translation information [in]
+ * @program_number BLAST program [in]
+ * @is_ooframe Out-of-frame translation if true [in]
+ * @target Structure being set up. [out]
+ */
+NCBI_XBLAST_EXPORT
+Int2 
+BlastTargetTranslationNew(BLAST_SequenceBlk* subject_blk,
+                              const Uint1* gen_code_string,
+                              EBlastProgramType program_number,
+                              Boolean is_ooframe,
+                              SBlastTargetTranslation** target);
 #ifdef __cplusplus
 }
 #endif
-#endif /* !__BLAST_UTIL__ */
+#endif /* !ALGO_BLAST_CORE__BLAST_UTIL__H */
