@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 9/94
 *
-* $Revision: 6.68 $
+* $Revision: 6.69 $
 *
 * File Description:  Manager for Bioseqs and BioseqSets
 *
@@ -38,261 +38,6 @@
 * Date	   Name        Description of modification
 * -------  ----------  -----------------------------------------------------
 *
-*
-* $Log: seqmgr.h,v $
-* Revision 6.68  2008/09/05 21:09:20  kans
-* for best protref, unprocessed 0 preferred over preprotein 1 preferred over mat peptide 2
-*
-* Revision 6.67  2007/05/29 15:14:32  bollin
-* Made SeqMgrGetOmdpForBioseq extern.
-*
-* Revision 6.66  2007/04/25 14:18:37  kans
-* added BioseqFindSpecial to skip bioseq_cache - needed by validator to handle IDs in any order - ClearBioseqFindCache could be fooled by order
-*
-* Revision 6.65  2007/04/24 17:55:26  kans
-* ClearBioseqFindCache frees internal omdp and se caches which can thwart detection of colliding IDs
-*
-* Revision 6.64  2006/10/30 17:15:36  kans
-* added SeqMgrClearBioseqIndex
-*
-* Revision 6.63  2006/10/27 15:00:34  kans
-* added prototype for AdvcLockFarComponents
-*
-* Revision 6.62  2006/08/29 16:02:45  bollin
-* fixed bug in reloading cached Bioseqs without user fetch procs in the
-* ObjMgrData record.
-* Added function for locking Bioseqs in an alignment that are cacheable
-*
-* Revision 6.61  2006/07/13 17:06:39  bollin
-* use Uint4 instead of Uint2 for itemID values
-* removed unused variables
-* resolved compiler warnings
-*
-* Revision 6.60  2006/04/13 20:02:15  kans
-* LookupFarSeqIDs takes inference parameter
-*
-* Revision 6.59  2006/02/16 20:24:32  kans
-* added bad_order and mixed_strand fields to feature index - to be used for get best gene overlap function in cases of trans-splicing
-*
-* Revision 6.58  2005/08/18 21:02:34  kans
-* defined SMFidItemPtr structure and added featsByFeatID and numfids fields, in preparation for indexing by feature ID
-*
-* Revision 6.57  2005/04/01 20:57:48  kans
-* SIDPreCacheFunc and LookupFarSeqIDs take new argument for SP block and other places for gi numbers to hide
-*
-* Revision 6.56  2004/11/18 22:21:11  kans
-* made FetchFromGiSeqIdCache extern - needed to prevent unnecessary precache fetches
-*
-* Revision 6.55  2004/11/17 22:03:43  kans
-* added SeqMgrFindAnnotDescByID, fields in BspExtra structure - still need to finish indexing implementation
-*
-* Revision 6.54  2004/06/22 17:37:25  kans
-* added FreeSeqIdGiCache
-*
-* Revision 6.53  2004/02/24 20:57:45  kans
-* added genesByLocusTag field, SeqMgrGetNextGeneByLocusTag function, now that locus_tag should be a unique identifier
-*
-* Revision 6.52  2003/10/23 17:40:01  kans
-* added SeqMgrGetOverlappingOperon and bspextra operonsByPos and numoperons fields
-*
-* Revision 6.51  2003/09/22 16:13:20  kans
-* LockFarComponentsEx takes new SeqLocPtr parameter
-*
-* Revision 6.50  2003/02/12 14:20:47  kans
-* added IsNonGappedLiteral, used to allow compressed deltas as (previously always raw) parts of segsets
-*
-* Revision 6.49  2003/01/21 20:15:01  kans
-* support for SeqMgrSetSeqIdSetFunc and GetSeqIdSetForGI needed for validator
-*
-* Revision 6.48  2002/06/10 13:50:43  kans
-* added SeqMgrSetLenFunc, SeqMgrSetAccnVerFunc
-*
-* Revision 6.47  2002/05/08 18:58:10  kans
-* itemID is Uint4
-*
-* Revision 6.46  2002/04/12 20:42:39  kans
-* LookupFarSeqIDs has separate parameter for alignments and history
-*
-* Revision 6.45  2002/03/14 16:40:03  kans
-* SeqMgrIndexFeaturesEx takes dorevfeats, SeqMgrExploreFeaturesRev and featsByRev added for asn2gb
-*
-* Revision 6.44  2002/03/07 16:12:30  kans
-* TrimLocInSegment for asn2gb master style to constrain feature locations within the part sequence range used by the contig
-*
-* Revision 6.43  2001/12/28 13:19:12  kans
-* added seq_id_precache_func, SeqMgrSetPreCache, LookupFarSeqIDs
-*
-* Revision 6.42  2001/12/26 15:29:23  kans
-* FetchFromSeqIdGiCache and RecordInSeqIdGiCache are extern
-*
-* Revision 6.41  2001/11/15 18:15:48  kans
-* set bsp->omdp at creation, SeqMgrDeleteIndexesInRecord sets omdp->bulkIndexFree
-*
-* Revision 6.40  2001/10/02 21:46:51  kans
-* added SeqEntryAsnOut (JO)
-*
-* Revision 6.39  2001/10/01 11:30:38  kans
-* added LockFarComponentsEx, which allows far feature products and locations to be locked as well as far seg or delta components
-*
-* Revision 6.38  2001/09/12 18:26:08  kans
-* added bspIndex to bspextra, made SeqMgrGetBioseqContext much more efficient for large sets
-*
-* Revision 6.37  2001/04/26 19:48:47  kans
-* added SeqMgrGetFeatureByLabel, bspextra->featsByLabel
-*
-* Revision 6.36  2001/03/29 22:31:12  kans
-* added fields for descriptor indexing
-*
-* Revision 6.35  2000/11/03 00:13:01  kans
-* added from and to parameters to GenomePartToSegmentMap, needed because delta contig can refer to the same accession multiple times
-*
-* Revision 6.34  2000/09/28 20:57:08  kans
-* added LockFarComponents and UnlockFarComponents
-*
-* Revision 6.33  2000/07/10 23:28:49  kans
-* GenomePartToSegmentMap only takes two Bioseq parameters
-*
-* Revision 6.32  2000/07/10 15:17:08  kans
-* added GenomePartToSegmentMap for acc->contig remapping
-*
-* Revision 6.31  2000/05/24 21:13:49  ostell
-* added SeqMgrHoldIndexing() support
-*
-* Revision 6.30  2000/01/07 22:58:04  kans
-* added dnaStop field to map sig_peptide, etc., onto DNA coordinates to choose proper flatfile segment for display
-*
-* Revision 6.29  2000/01/07 02:32:31  kans
-* added SeqMgrGetSfpProductList for access to bspextra->prodlisthead
-*
-* Revision 6.28  2000/01/07 02:17:45  kans
-* removed featsBySap, added prodlisthead, to support gather by get_feats_product
-*
-* Revision 6.27  2000/01/05 19:16:46  kans
-* added featsBySap field to be used to speed up targeted feature gather
-*
-* Revision 6.26  1999/12/27 19:57:45  kans
-* binary search needed precomputed index to handle overlapping gene (mRNA, CDS, etc.) features, so after binary search it can back up to the appropriate first feature to check in a linear scan
-*
-* Revision 6.25  1999/11/05 19:53:15  kans
-* SeqMgrIndexAlignments called by SeqMgrIndexFeatures, but can now be called separately even if you do not index features
-*
-* Revision 6.24  1999/08/25 22:08:00  kans
-* made MakeReversedSeqIdString public
-*
-* Revision 6.23  1999/07/21 23:53:56  kans
-* added SeqMgrFindSeqAlignByID
-*
-* Revision 6.22  1999/04/01 20:44:14  kans
-* Int2 lengths to Int4 to allow CountGapsInDeltaSeq with buffer > 32K
-*
-* Revision 6.21  1998/11/24 22:21:25  kans
-* index mRNA and CDS by position, allow arbitrary sorted feature array index
-*
-* Revision 6.20  1998/10/22 23:41:51  kans
-* feat context has bsp, partial flags, far location flag, GetDesired functions can work on entity entity if using itemID
-*
-* Revision 6.19  1998/10/22 16:05:56  kans
-* removed labeltype parameter from SeqMgrIndexFeatures, changed index parameter/field to Uint2
-*
-* Revision 6.18  1998/09/22 16:55:53  kans
-* added SeqMgrGetDesiredFeature and position index field
-*
-* Revision 6.17  1998/09/01 19:25:26  kans
-* context parameter in get best protein, get cds/rna given product
-*
-* Revision 6.16  1998/08/21 20:19:01  kans
-* added SeqMgrExploreSegments, indexing features on segmented bioseq
-*
-* Revision 6.15  1998/08/14 15:40:39  kans
-* SeqMgrMapPartToSegmentedBioseq neede LIBCALL, speeded up function by adding map up on part if fetched
-*
-* Revision 6.14  1998/08/13 22:31:47  kans
-* SeqMgrMapPartToSegmentedBioseq to speed up GetOffsetInBioseq, start of indexing segments, also index biosource by location for binary search (Wheelan)
-*
-* Revision 6.13  1998/08/12 21:10:38  kans
-* added parts index to speed segmented bioseq mapping
-*
-* Revision 6.12  1998/07/23 00:40:41  kans
-* added SeqMgrGetOverlappingPub, second gene and pub if spanning origin
-*
-* Revision 6.11  1998/07/06 15:30:21  kans
-* scope on index explore, added SeqMgrExploreBioseqs
-*
-* Revision 6.10  1998/07/01 19:13:21  kans
-* SMFeatBlock.data is allocated array of reasonable size
-*
-* Revision 6.9  1998/06/30 12:56:50  kans
-* code fixes, public functions moved to explore.h
-*
-* Revision 6.8  1998/06/29 23:37:42  kans
-* added context structure for all explores, index every bioseq in an entity
-*
-* Revision 6.7  1998/06/29 01:33:31  kans
-* added SeqMgrGetNextDescriptor and SeqMgrGetNextFeature
-*
-* Revision 6.6  1998/06/29 00:23:57  kans
-* several changes to new indexing functions
-*
-* Revision 6.5  1998/06/28 02:38:20  kans
-* simplified filters, finished best gene, explore functions
-*
-* Revision 6.4  1998/06/27 22:23:47  kans
-* improvements and further implementation of new indexing, exploration functions
-*
-* Revision 6.3  1998/06/26 22:36:28  kans
-* initial work on tracking sorted features, and cds and prot links, for rapid collection
-*
-* Revision 6.2  1997/11/19 22:14:45  ostell
-* added support for multithreaded programs
-*
-* Revision 6.1  1997/09/11 15:55:43  ostell
-* Added support for SetColor messages
-*
-* Revision 6.0  1997/08/25 18:07:09  madden
-* Revision changed to 6.0
-*
-* Revision 5.7  1997/07/28 13:29:45  ostell
-* Moved GetUniGeneIDForSeqId() to seqmgr.c
-*
-* Revision 5.6  1997/06/19 18:38:47  vakatov
-* [WIN32,MSVC++]  Adopted for the "NCBIOBJ.LIB" DLL'ization
-*
-* Revision 5.5  1997/01/23 22:37:14  ostell
-* minor change to seqmgr.h for new indexing
-*
- * Revision 5.3  1997/01/08  22:49:22  tatiana
- * buf and buflen arguments added to CountGapsInDeltaSeq()
- *
- * Revision 5.2  1996/07/25  02:32:26  ostell
- * added CountGapsInDeltaSeq()
- *
- * Revision 5.1  1996/07/19  22:13:13  ostell
- * added SpreadGapsInDeltaSeq()
- *
- * Revision 5.0  1996/05/28  13:23:23  ostell
- * Set to revision 5.0
- *
- * Revision 4.3  1995/12/22  14:43:59  ostell
- * added reload code to BioseqLockById
- * break out relad from cache code to be used as part of gather locking
- * with BioseqReload
- *
- * Revision 4.2  1995/12/04  21:40:05  ostell
- * added GetSeqIdForGI() and GetGIForSeqId()
- *
- * Revision 4.1  1995/09/30  03:38:31  ostell
- * Changed ObjMgrMessage functions to pass a structure
- * Added support for selecting regions
- * Added ability to remove entity when no more views on it
- *
- * Revision 4.0  1995/07/26  13:49:01  ostell
- * force revision to 4.0
- *
- * Revision 1.10  1995/05/15  21:46:05  ostell
- * added Log line
- *
-*
-*
 * ==========================================================================
 */
 
@@ -1233,7 +978,10 @@ NLM_EXTERN Boolean SeqEntryAsnOut (SeqEntryPtr sep, SeqIdPtr sip,
                                     Int2 retcode, AsnIoPtr aipout);
 
 
-extern ObjMgrDataPtr SeqMgrGetOmdpForBioseq (BioseqPtr bsp);
+NLM_EXTERN ObjMgrDataPtr SeqMgrGetOmdpForBioseq (BioseqPtr bsp);
+
+NLM_EXTERN Pointer SeqMgrGetExtraDataForOmdp (ObjMgrDataPtr omdp);
+
 
 #ifdef __cplusplus
 }
