@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 7/13/91
 *
-* $Revision: 6.58 $
+* $Revision: 6.60 $
 *
 * File Description:  Ports onto Bioseqs
 *
@@ -38,239 +38,6 @@
 * Date	   Name        Description of modification
 * -------  ----------  -----------------------------------------------------
 *
-*
-* $Log: seqport.h,v $
-* Revision 6.58  2007/05/30 18:10:06  kans
-* added KNOWN_GAP_AS_PLUS to distinguish known-length from unknown-length gaps, use for validation
-*
-* Revision 6.57  2006/12/20 20:08:24  kans
-* added SUPPRESS_VIRT_SEQ and STREAM_VIRT_AS_PLUS, moved STREAM_CORRECT_INVAL
-*
-* Revision 6.56  2006/12/18 15:42:58  kans
-* made MakeCodeBreakList public so validator can check for unnecessary transl excepts
-*
-* Revision 6.55  2006/11/15 18:02:59  kans
-* ProteinFromCdRegionExEx and TransTableTranslateCdRegionEx take farProdFetchOK argument
-*
-* Revision 6.54  2006/11/06 17:16:38  kans
-* added stream flag to allow negative gi numbers by NCBI ID group
-*
-* Revision 6.53  2006/07/13 17:06:39  bollin
-* use Uint4 instead of Uint2 for itemID values
-* removed unused variables
-* resolved compiler warnings
-*
-* Revision 6.52  2006/05/19 18:40:07  kans
-* added protein equivalent of nucleotide SeqSearch finite state machine
-*
-* Revision 6.51  2005/08/24 15:14:31  kans
-* modified MolWtForLoc to use StreamCache, added MolWtForBsp and MolWtForStr
-*
-* Revision 6.50  2005/06/01 20:27:06  kans
-* added MapNa4ByteToIUPACplusGapString
-*
-* Revision 6.49  2005/03/15 14:35:44  kans
-* seqport stream gap control flags (2-bit set) are STREAM_EXPAND_GAPS, GAP_TO_SINGLE_DASH, and EXPAND_GAPS_TO_DASHES
-*
-* Revision 6.48  2005/03/14 22:48:11  kans
-* inserted STREAM_INDICATE_GAPS before STREAM_CORRECT_INVAL, will mark gap with 251 instead of N or X
-*
-* Revision 6.47  2004/11/29 17:12:42  kans
-* added SearchFlgType for expandPattern, allowOneMismatch, justTopStrand arguments
-*
-* Revision 6.46  2004/11/26 18:53:09  kans
-* SeqSearchAddNucleotidePattern takes expandPattern, allowOneMismatch arguments
-*
-* Revision 6.45  2004/10/27 22:15:34  kans
-* added STREAM_CORRECT_INVAL flag to SeqPortStream
-*
-* Revision 6.44  2004/07/16 19:37:37  kans
-* SeqPortStream and FastaStream functions return Int4, negative count if any fetch failures
-*
-* Revision 6.43  2004/05/12 18:55:33  kans
-* StreamCache takes SeqLocPtr as well as BioseqPtr optional arguments, slp version is equivalent of SeqPortNewByLoc
-*
-* Revision 6.42  2004/04/27 20:09:26  kans
-* StreamCacheGetResidue returns Uint1 because Char might be signed, preventing IS_residue from working
-*
-* Revision 6.41  2004/04/27 18:15:12  kans
-* added StreamCache functions that provide buffered request-driven access to sequence via SeqPortStream
-*
-* Revision 6.40  2004/04/14 12:39:01  kans
-* SeqPortStreamLoc is public function, SeqPortStreamRaw directly uncompresses byte store, avoids any SeqPort calls - still need more efficient way to reverse complement without a big buffer
-*
-* Revision 6.39  2004/04/08 20:19:21  kans
-* SeqPortStreamInt is external
-*
-* Revision 6.38  2004/03/15 19:54:54  kans
-* SeqPortStream takes expandable bit flags parameter
-*
-* Revision 6.37  2004/02/25 19:07:45  kans
-* ProteinFromCdRegionExEx and TransTableTranslateCdRegionEx return alternative start flag
-*
-* Revision 6.36  2003/11/18 17:08:46  kans
-* added MapNa4ByteTo4BitString, use in seqport read and get char
-*
-* Revision 6.35  2003/11/17 22:44:31  kans
-* added MapNa2ByteTo4BitString in preparation for faster SeqPortRead from 2na to 4na
-*
-* Revision 6.34  2003/11/05 21:17:22  bollin
-* added new option for Retranslate Coding Regions to handle stop codons at end of complete CDS during retranslate while ignoring stop codons
-*
-* Revision 6.33  2002/11/11 18:02:40  kans
-* added SeqPortStream to efficiently stream through a sequence
-*
-* Revision 6.32  2002/07/08 15:08:59  kans
-* made ReadCodingRegionBases extern
-*
-* Revision 6.31  2002/05/13 21:41:32  kans
-* added ConvertNsToGaps
-*
-* Revision 6.30  2001/02/18 20:58:52  kans
-* added GetSequenceByBsp
-*
-* Revision 6.29  2000/12/18 18:03:26  kans
-* added GetScoresbySeqId
-*
-* Revision 6.28  2000/09/24 23:31:18  kans
-* added GetSequenceByFeature
-*
-* Revision 6.27  2000/09/24 22:52:47  kans
-* added GetSequenceByIdOrAccnDotVer
-*
-* Revision 6.26  2000/09/05 21:33:50  kans
-* productInterval_to_locationIntervals replaces aaInterval_to_dnaIntervals, also works for mRNA feature (JO)
-*
-* Revision 6.25  2000/08/31 18:12:54  shavirin
-* Added new function TransTableFreeAll().
-*
-* Revision 6.24  2000/08/11 18:09:49  kans
-* GetScoresbyAccessionDotVersion passes length back through new parameter
-*
-* Revision 6.23  2000/08/11 18:03:25  kans
-* added GetScoresbyAccessionDotVersion - prototyped in seqport.h but implemented in sqnutil2.c
-*
-* Revision 6.22  2000/08/10 17:22:38  kans
-* added GetDNAbyAccessionDotVersion for genome processing effort
-*
-* Revision 6.21  2000/08/04 15:45:22  kans
-* added ContigRevComp - still need to implement for delta bioseqs
-*
-* Revision 6.20  2000/08/03 19:02:54  kans
-* added PersistentTransTableByGenCode and PersistentTransTableByCdRegion
-*
-* Revision 6.19  2000/08/01 20:02:58  kans
-* separate macros for IsOrfStart, IsAmbigStart, IsAnyStart
-*
-* Revision 6.18  2000/07/22 22:45:37  kans
-* more work on trans table translation functions
-*
-* Revision 6.17  2000/07/21 15:28:36  kans
-* first pass at TransTableTranslate functions - more work remains
-*
-* Revision 6.16  2000/07/05 17:02:12  kans
-* added spp->gapIsZero, SeqPortSet_do_virtualEx, using ncbi4na with gap of 0 to distinguish quality scores under N versus quality scores under gap
-*
-* Revision 6.15  2000/05/23 20:41:17  ostell
-* added MolWtForLoc()
-*
-* Revision 6.14  1999/11/17 00:56:33  kans
-* improved seqsearch fsa, removed protein part, still need to allow single mismatch
-*
-* Revision 6.13  1999/11/12 21:00:50  kans
-* added TransTableProcessBioseq for 6-frame translation, SeqSearchAddNucleotidePattern and SeqSearchAddProteinPattern for SeqSearch
-*
-* Revision 6.12  1999/11/11 00:58:28  kans
-* added SeqSearch sequence search finite state machine - still need more functions to add protein patterns, read from rsite file
-*
-* Revision 6.11  1999/10/06 22:09:02  kans
-* ComposeCodonsRecognizedString to handle degenerate codons
-*
-* Revision 6.10  1999/08/06 20:22:19  kans
-* TransTable simplified to eliminate single and double letter states
-*
-* Revision 6.9  1999/08/06 02:20:16  kans
-* finite state machine for 6-frame translation and orf search enhanced to handle nucleotide ambiguity characters
-*
-* Revision 6.8  1999/02/12 20:48:24  kans
-* made fast byte expansion functions public
-*
-* Revision 6.7  1998/12/14 20:56:24  kans
-* dnaLoc_to_aaLoc takes allowTerminator parameter to handle stop codons created by polyA tail
-*
-* Revision 6.6  1998/11/16 21:10:08  kans
-* added IsATGStart and IsAltStart macros
-*
-* Revision 6.5  1998/11/16 17:20:31  kans
-* nextBase in codon fsa is Uint1, cast state array index to int in macros
-*
-* Revision 6.4  1998/11/14 00:30:21  kans
-* added TransTableInit and macros for 6-frame translation and orf-finding finite state machine
-*
-* Revision 6.3  1998/09/16 21:40:42  kans
-* added SPCacheQ for rapid 2na/4na to iupacna conversion
-*
-* Revision 6.2  1998/02/24 15:09:17  kans
-* made AAForCodon prototype public
-*
-* Revision 6.1  1997/09/16 15:31:31  kans
-* added aaFeatLoc_to_dnaFeatLoc (JO)
-*
-* Revision 6.0  1997/08/25 18:07:16  madden
-* Revision changed to 6.0
-*
-* Revision 5.5  1997/08/15 17:02:44  madden
-* Added new function ProteinFromCdRegionEx with remove_trailingX Boolean
-*
-* Revision 5.4  1997/06/19 18:38:52  vakatov
-* [WIN32,MSVC++]  Adopted for the "NCBIOBJ.LIB" DLL'ization
-*
-* Revision 5.3  1997/03/06 22:47:54  shavirin
-* Moved definitions for SPCompress functions from sequtil.h
-*
- * Revision 5.2  1996/08/09  15:27:47  ostell
- * added BioseqRev(), BioseqComp(), BioseqRevComp()
- *
- * Revision 5.1  1996/07/15  19:04:18  epstein
- * add new param to dnaLoc_to_aaLoc() to optionally report frame
- *
- * Revision 5.0  1996/05/28  13:23:23  ostell
- * Set to revision 5.0
- *
- * Revision 4.8  1996/01/30  16:28:52  ostell
- * fixed type in comment
- *
- * Revision 4.7  1996/01/30  16:24:04  ostell
- * added merge argument to dnaLoc_to_aaLoc()
- * change calls to SeqLocPackage
- *
- * Revision 4.6  1996/01/29  22:03:52  ostell
- * added aaLoc_to_dnaLoc() and dnsLoc_to_aaLoc()
- *
- * Revision 4.5  1996/01/28  07:00:05  ostell
- * made fisxes to support deeply nexted segmented seqports
- *
- * Revision 4.4  1996/01/27  22:19:00  ostell
- * added SeqPortSet_.. functions
- * refined support for virtual seqeunces
- *
- * Revision 4.3  1996/01/10  22:25:25  ostell
- * added aaInterval_to_seqloc()
- *
- * Revision 4.2  1995/12/29  21:31:44  ostell
- * made SeqPort helper functions public for use by edutil for delta seqs
- *
- * Revision 4.1  1995/12/26  22:29:34  ostell
- * added support for delta seq to SeqPort
- *
- * Revision 4.0  1995/07/26  13:49:01  ostell
- * force revision to 4.0
- *
- * Revision 2.14  1995/05/15  21:46:05  ostell
- * added Log line
- *
-*
-*
 * ==========================================================================
 */
 
@@ -680,7 +447,7 @@ NLM_EXTERN SeqLocPtr LIBCALL aaFeatLoc_to_dnaFeatLoc(SeqFeatPtr sfp, SeqLocPtr a
 *	DNA sequence through a CdRegion feature
 *
 ******************************************************************/
-NLM_EXTERN SeqLocPtr LIBCALL productInterval_to_locationIntervals (SeqFeatPtr sfp, Int4 aa_start, Int4 aa_stop);
+NLM_EXTERN SeqLocPtr LIBCALL productInterval_to_locationIntervals (SeqFeatPtr sfp, Int4 aa_start, Int4 aa_stop, Boolean aa_partialn);
 
 /*-------------- BioseqRevComp () ---------------------------*/
 /***********************************************************************
@@ -1059,6 +826,11 @@ NLM_EXTERN FloatHi MolWtForBsp (BioseqPtr bsp);
 NLM_EXTERN FloatHi MolWtForStr (CharPtr str);
 
 
+
+NLM_EXTERN Boolean LIBCALL ReverseSeqData (Uint1 seqtype, Int4 seqlen, SeqDataPtr sdp);
+NLM_EXTERN Boolean ComplementSeqData (Uint1 seqtype, Int4 seqlen, SeqDataPtr sdp);
+
+
 #ifdef __cplusplus
 }
 #endif
