@@ -9,7 +9,7 @@
 #include <asn.h>
 #endif
 
-static char * asnfilename = "asnloc.h62";
+static char * asnfilename = "asnloc.h64";
 static AsnValxNode avnx[7] = {
     {3,NULL,32,0.0,NULL } ,
     {20,"unknown" ,0,0.0,&avnx[2] } ,
@@ -19,10 +19,10 @@ static AsnValxNode avnx[7] = {
     {20,"both-rev" ,4,0.0,&avnx[6] } ,
     {20,"other" ,255,0.0,NULL } };
 
-static AsnType atx[91] = {
-  {401, "Seq-id" ,1,0,0,0,0,1,0,0,NULL,&atx[44],&atx[1],0,&atx[45]} ,
+static AsnType atx[92] = {
+  {401, "Seq-id" ,1,0,0,0,0,1,0,0,NULL,&atx[45],&atx[1],0,&atx[46]} ,
   {0, "local" ,128,0,0,0,0,0,0,0,NULL,&atx[2],NULL,0,&atx[3]} ,
-  {409, "Object-id" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[59]} ,
+  {409, "Object-id" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[60]} ,
   {0, "gibbsq" ,128,1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[5]} ,
   {302, "INTEGER" ,0,2,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
   {0, "gibbmt" ,128,2,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[6]} ,
@@ -46,7 +46,7 @@ static AsnType atx[91] = {
   {416, "Patent-seq-id" ,1,0,0,0,0,0,0,0,NULL,&atx[12],&atx[24],0,&atx[34]} ,
   {0, "seqid" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[25]} ,
   {0, "cit" ,128,1,0,0,0,0,0,0,NULL,&atx[26],NULL,0,NULL} ,
-  {413, "Id-pat" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[90]} ,
+  {413, "Id-pat" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[91]} ,
   {0, "other" ,128,9,0,0,0,0,0,0,NULL,&atx[14],NULL,0,&atx[28]} ,
   {0, "general" ,128,10,0,0,0,0,0,0,NULL,&atx[29],NULL,0,&atx[30]} ,
   {411, "Dbtag" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[39]} ,
@@ -56,64 +56,65 @@ static AsnType atx[91] = {
   {0, "pdb" ,128,14,0,0,0,0,0,0,NULL,&atx[34],NULL,0,&atx[40]} ,
   {417, "PDB-seq-id" ,1,0,0,0,0,0,0,0,NULL,&atx[12],&atx[35],0,&atx[36]} ,
   {0, "mol" ,128,0,0,0,0,0,0,0,NULL,&atx[36],NULL,0,&atx[37]} ,
-  {418, "PDB-mol-id" ,1,0,0,0,0,0,0,0,NULL,&atx[10],NULL,0,&atx[79]} ,
+  {418, "PDB-mol-id" ,1,0,0,0,0,0,0,0,NULL,&atx[10],NULL,0,&atx[80]} ,
   {0, "chain" ,128,1,0,0,1,0,0,0,&avnx[0],&atx[4],NULL,0,&atx[38]} ,
   {0, "rel" ,128,2,0,1,0,0,0,0,NULL,&atx[39],NULL,0,NULL} ,
   {412, "Date" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[26]} ,
   {0, "tpg" ,128,15,0,0,0,0,0,0,NULL,&atx[14],NULL,0,&atx[41]} ,
   {0, "tpe" ,128,16,0,0,0,0,0,0,NULL,&atx[14],NULL,0,&atx[42]} ,
   {0, "tpd" ,128,17,0,0,0,0,0,0,NULL,&atx[14],NULL,0,&atx[43]} ,
-  {0, "gpipe" ,128,18,0,0,0,0,0,0,NULL,&atx[14],NULL,0,NULL} ,
+  {0, "gpipe" ,128,18,0,0,0,0,0,0,NULL,&atx[14],NULL,0,&atx[44]} ,
+  {0, "named-annot-track" ,128,19,0,0,0,0,0,0,NULL,&atx[14],NULL,0,NULL} ,
   {315, "CHOICE" ,0,-1,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
-  {402, "Seq-loc" ,1,0,0,0,0,1,0,0,NULL,&atx[44],&atx[46],0,&atx[51]} ,
-  {0, "null" ,128,0,0,0,0,0,0,0,NULL,&atx[47],NULL,0,&atx[48]} ,
+  {402, "Seq-loc" ,1,0,0,0,0,1,0,0,NULL,&atx[45],&atx[47],0,&atx[52]} ,
+  {0, "null" ,128,0,0,0,0,0,0,0,NULL,&atx[48],NULL,0,&atx[49]} ,
   {305, "NULL" ,0,5,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
-  {0, "empty" ,128,1,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[49]} ,
-  {0, "whole" ,128,2,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[50]} ,
-  {0, "int" ,128,3,0,0,0,0,0,0,NULL,&atx[51],NULL,0,&atx[61]} ,
-  {403, "Seq-interval" ,1,0,0,0,0,1,0,0,NULL,&atx[12],&atx[52],0,&atx[62]} ,
-  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[53]} ,
-  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[54]} ,
-  {0, "strand" ,128,2,0,1,0,0,0,0,NULL,&atx[55],NULL,0,&atx[57]} ,
-  {407, "Na-strand" ,1,0,0,0,0,1,0,0,NULL,&atx[56],&avnx[1],0,&atx[7]} ,
+  {0, "empty" ,128,1,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[50]} ,
+  {0, "whole" ,128,2,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[51]} ,
+  {0, "int" ,128,3,0,0,0,0,0,0,NULL,&atx[52],NULL,0,&atx[62]} ,
+  {403, "Seq-interval" ,1,0,0,0,0,1,0,0,NULL,&atx[12],&atx[53],0,&atx[63]} ,
+  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[54]} ,
+  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[55]} ,
+  {0, "strand" ,128,2,0,1,0,0,0,0,NULL,&atx[56],NULL,0,&atx[58]} ,
+  {407, "Na-strand" ,1,0,0,0,0,1,0,0,NULL,&atx[57],&avnx[1],0,&atx[7]} ,
   {310, "ENUMERATED" ,0,10,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
-  {0, "id" ,128,3,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[58]} ,
-  {0, "fuzz-from" ,128,4,0,1,0,0,0,0,NULL,&atx[59],NULL,0,&atx[60]} ,
+  {0, "id" ,128,3,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[59]} ,
+  {0, "fuzz-from" ,128,4,0,1,0,0,0,0,NULL,&atx[60],NULL,0,&atx[61]} ,
   {410, "Int-fuzz" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[29]} ,
-  {0, "fuzz-to" ,128,5,0,1,0,0,0,0,NULL,&atx[59],NULL,0,NULL} ,
-  {0, "packed-int" ,128,4,0,0,0,0,0,0,NULL,&atx[62],NULL,0,&atx[65]} ,
-  {404, "Packed-seqint" ,1,0,0,0,0,1,0,0,NULL,&atx[64],&atx[63],0,&atx[66]} ,
-  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[51],NULL,0,NULL} ,
+  {0, "fuzz-to" ,128,5,0,1,0,0,0,0,NULL,&atx[60],NULL,0,NULL} ,
+  {0, "packed-int" ,128,4,0,0,0,0,0,0,NULL,&atx[63],NULL,0,&atx[66]} ,
+  {404, "Packed-seqint" ,1,0,0,0,0,1,0,0,NULL,&atx[65],&atx[64],0,&atx[67]} ,
+  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[52],NULL,0,NULL} ,
   {312, "SEQUENCE OF" ,0,16,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
-  {0, "pnt" ,128,5,0,0,0,0,0,0,NULL,&atx[66],NULL,0,&atx[71]} ,
-  {405, "Seq-point" ,1,0,0,0,0,1,0,0,NULL,&atx[12],&atx[67],0,&atx[72]} ,
-  {0, "point" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[68]} ,
-  {0, "strand" ,128,1,0,1,0,0,0,0,NULL,&atx[55],NULL,0,&atx[69]} ,
-  {0, "id" ,128,2,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[70]} ,
-  {0, "fuzz" ,128,3,0,1,0,0,0,0,NULL,&atx[59],NULL,0,NULL} ,
-  {0, "packed-pnt" ,128,6,0,0,0,0,0,0,NULL,&atx[72],NULL,0,&atx[78]} ,
-  {406, "Packed-seqpnt" ,1,0,0,0,0,1,0,0,NULL,&atx[12],&atx[73],0,&atx[55]} ,
-  {0, "strand" ,128,0,0,1,0,0,0,0,NULL,&atx[55],NULL,0,&atx[74]} ,
-  {0, "id" ,128,1,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[75]} ,
-  {0, "fuzz" ,128,2,0,1,0,0,0,0,NULL,&atx[59],NULL,0,&atx[76]} ,
-  {0, "points" ,128,3,0,0,0,0,0,0,NULL,&atx[64],&atx[77],0,NULL} ,
+  {0, "pnt" ,128,5,0,0,0,0,0,0,NULL,&atx[67],NULL,0,&atx[72]} ,
+  {405, "Seq-point" ,1,0,0,0,0,1,0,0,NULL,&atx[12],&atx[68],0,&atx[73]} ,
+  {0, "point" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[69]} ,
+  {0, "strand" ,128,1,0,1,0,0,0,0,NULL,&atx[56],NULL,0,&atx[70]} ,
+  {0, "id" ,128,2,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[71]} ,
+  {0, "fuzz" ,128,3,0,1,0,0,0,0,NULL,&atx[60],NULL,0,NULL} ,
+  {0, "packed-pnt" ,128,6,0,0,0,0,0,0,NULL,&atx[73],NULL,0,&atx[79]} ,
+  {406, "Packed-seqpnt" ,1,0,0,0,0,1,0,0,NULL,&atx[12],&atx[74],0,&atx[56]} ,
+  {0, "strand" ,128,0,0,1,0,0,0,0,NULL,&atx[56],NULL,0,&atx[75]} ,
+  {0, "id" ,128,1,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[76]} ,
+  {0, "fuzz" ,128,2,0,1,0,0,0,0,NULL,&atx[60],NULL,0,&atx[77]} ,
+  {0, "points" ,128,3,0,0,0,0,0,0,NULL,&atx[65],&atx[78],0,NULL} ,
   {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,NULL} ,
-  {0, "mix" ,128,7,0,0,0,0,0,0,NULL,&atx[79],NULL,0,&atx[81]} ,
-  {419, "Seq-loc-mix" ,1,0,0,0,0,0,0,0,NULL,&atx[64],&atx[80],0,&atx[82]} ,
-  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[45],NULL,0,NULL} ,
-  {0, "equiv" ,128,8,0,0,0,0,0,0,NULL,&atx[82],NULL,0,&atx[85]} ,
-  {420, "Seq-loc-equiv" ,1,0,0,0,0,0,0,0,NULL,&atx[84],&atx[83],0,&atx[86]} ,
-  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[45],NULL,0,NULL} ,
+  {0, "mix" ,128,7,0,0,0,0,0,0,NULL,&atx[80],NULL,0,&atx[82]} ,
+  {419, "Seq-loc-mix" ,1,0,0,0,0,0,0,0,NULL,&atx[65],&atx[81],0,&atx[83]} ,
+  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[46],NULL,0,NULL} ,
+  {0, "equiv" ,128,8,0,0,0,0,0,0,NULL,&atx[83],NULL,0,&atx[86]} ,
+  {420, "Seq-loc-equiv" ,1,0,0,0,0,0,0,0,NULL,&atx[85],&atx[84],0,&atx[87]} ,
+  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[46],NULL,0,NULL} ,
   {314, "SET OF" ,0,17,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
-  {0, "bond" ,128,9,0,0,0,0,0,0,NULL,&atx[86],NULL,0,&atx[89]} ,
-  {421, "Seq-bond" ,1,0,0,0,0,0,0,0,NULL,&atx[12],&atx[87],0,NULL} ,
-  {0, "a" ,128,0,0,0,0,0,0,0,NULL,&atx[66],NULL,0,&atx[88]} ,
-  {0, "b" ,128,1,0,1,0,0,0,0,NULL,&atx[66],NULL,0,NULL} ,
-  {0, "feat" ,128,10,0,0,0,0,0,0,NULL,&atx[90],NULL,0,NULL} ,
+  {0, "bond" ,128,9,0,0,0,0,0,0,NULL,&atx[87],NULL,0,&atx[90]} ,
+  {421, "Seq-bond" ,1,0,0,0,0,0,0,0,NULL,&atx[12],&atx[88],0,NULL} ,
+  {0, "a" ,128,0,0,0,0,0,0,0,NULL,&atx[67],NULL,0,&atx[89]} ,
+  {0, "b" ,128,1,0,1,0,0,0,0,NULL,&atx[67],NULL,0,NULL} ,
+  {0, "feat" ,128,10,0,0,0,0,0,0,NULL,&atx[91],NULL,0,NULL} ,
   {414, "Feat-id" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[14]} };
 
 static AsnModule ampx[1] = {
-  { "NCBI-Seqloc" , "asnloc.h62",&atx[0],NULL,NULL,0,0} };
+  { "NCBI-Seqloc" , "asnloc.h64",&atx[0],NULL,NULL,0,0} };
 
 static AsnValxNodePtr avn = avnx;
 static AsnTypePtr at = atx;
@@ -147,45 +148,46 @@ static AsnModulePtr amp = ampx;
 #define SEQ_ID_tpe &at[41]
 #define SEQ_ID_tpd &at[42]
 #define SEQ_ID_gpipe &at[43]
+#define SEQ_ID_named_annot_track &at[44]
 
-#define SEQ_LOC &at[45]
-#define SEQ_LOC_null &at[46]
-#define SEQ_LOC_empty &at[48]
-#define SEQ_LOC_whole &at[49]
-#define SEQ_LOC_int &at[50]
-#define SEQ_LOC_packed_int &at[61]
-#define SEQ_LOC_pnt &at[65]
-#define SEQ_LOC_packed_pnt &at[71]
-#define SEQ_LOC_mix &at[78]
-#define SEQ_LOC_equiv &at[81]
-#define SEQ_LOC_bond &at[85]
-#define SEQ_LOC_feat &at[89]
+#define SEQ_LOC &at[46]
+#define SEQ_LOC_null &at[47]
+#define SEQ_LOC_empty &at[49]
+#define SEQ_LOC_whole &at[50]
+#define SEQ_LOC_int &at[51]
+#define SEQ_LOC_packed_int &at[62]
+#define SEQ_LOC_pnt &at[66]
+#define SEQ_LOC_packed_pnt &at[72]
+#define SEQ_LOC_mix &at[79]
+#define SEQ_LOC_equiv &at[82]
+#define SEQ_LOC_bond &at[86]
+#define SEQ_LOC_feat &at[90]
 
-#define SEQ_INTERVAL &at[51]
-#define SEQ_INTERVAL_from &at[52]
-#define SEQ_INTERVAL_to &at[53]
-#define SEQ_INTERVAL_strand &at[54]
-#define SEQ_INTERVAL_id &at[57]
-#define SEQ_INTERVAL_fuzz_from &at[58]
-#define SEQ_INTERVAL_fuzz_to &at[60]
+#define SEQ_INTERVAL &at[52]
+#define SEQ_INTERVAL_from &at[53]
+#define SEQ_INTERVAL_to &at[54]
+#define SEQ_INTERVAL_strand &at[55]
+#define SEQ_INTERVAL_id &at[58]
+#define SEQ_INTERVAL_fuzz_from &at[59]
+#define SEQ_INTERVAL_fuzz_to &at[61]
 
-#define PACKED_SEQINT &at[62]
-#define PACKED_SEQINT_E &at[63]
+#define PACKED_SEQINT &at[63]
+#define PACKED_SEQINT_E &at[64]
 
-#define SEQ_POINT &at[66]
-#define SEQ_POINT_point &at[67]
-#define SEQ_POINT_strand &at[68]
-#define SEQ_POINT_id &at[69]
-#define SEQ_POINT_fuzz &at[70]
+#define SEQ_POINT &at[67]
+#define SEQ_POINT_point &at[68]
+#define SEQ_POINT_strand &at[69]
+#define SEQ_POINT_id &at[70]
+#define SEQ_POINT_fuzz &at[71]
 
-#define PACKED_SEQPNT &at[72]
-#define PACKED_SEQPNT_strand &at[73]
-#define PACKED_SEQPNT_id &at[74]
-#define PACKED_SEQPNT_fuzz &at[75]
-#define PACKED_SEQPNT_points &at[76]
-#define PACKED_SEQPNT_points_E &at[77]
+#define PACKED_SEQPNT &at[73]
+#define PACKED_SEQPNT_strand &at[74]
+#define PACKED_SEQPNT_id &at[75]
+#define PACKED_SEQPNT_fuzz &at[76]
+#define PACKED_SEQPNT_points &at[77]
+#define PACKED_SEQPNT_points_E &at[78]
 
-#define NA_STRAND &at[55]
+#define NA_STRAND &at[56]
 
 #define GIIMPORT_ID &at[7]
 #define GIIMPORT_ID_id &at[8]
@@ -209,12 +211,12 @@ static AsnModulePtr amp = ampx;
 
 #define PDB_MOL_ID &at[36]
 
-#define SEQ_LOC_MIX &at[79]
-#define SEQ_LOC_MIX_E &at[80]
+#define SEQ_LOC_MIX &at[80]
+#define SEQ_LOC_MIX_E &at[81]
 
-#define SEQ_LOC_EQUIV &at[82]
-#define SEQ_LOC_EQUIV_E &at[83]
+#define SEQ_LOC_EQUIV &at[83]
+#define SEQ_LOC_EQUIV_E &at[84]
 
-#define SEQ_BOND &at[86]
-#define SEQ_BOND_a &at[87]
-#define SEQ_BOND_b &at[88]
+#define SEQ_BOND &at[87]
+#define SEQ_BOND_a &at[88]
+#define SEQ_BOND_b &at[89]
