@@ -1,4 +1,4 @@
-/*  $Id: ncbi_dispd.c,v 6.87 2008/02/14 17:25:50 kazimird Exp $
+/* $Id: ncbi_dispd.c,v 6.93 2009/02/04 19:29:34 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -60,7 +60,7 @@ extern "C" {
     static void        s_Close      (SERV_ITER);
 
     static const SSERV_VTable s_op = {
-        s_Reset, s_GetNextInfo, s_Update, 0/*Penalize*/, s_Close, "DISPD"
+        s_Reset, s_GetNextInfo, s_Update, 0/*Feedback*/, s_Close, "DISPD"
     };
 #ifdef __cplusplus
 } /* extern "C" */
@@ -68,11 +68,13 @@ extern "C" {
 
 
 struct SDISPD_Data {
-    int/*bool*/    disp_fail;
+    short/*bool*/  eof;  /* no more resolves */
+    short/*bool*/  fail; /* no more connects */
     SConnNetInfo*  net_info;
     SLB_Candidate* cand;
     size_t         n_cand;
     size_t         a_cand;
+    size_t         n_skip;
 };
 
 
@@ -111,13 +113,24 @@ static int/*bool*/ s_AddServerInfo(struct SDISPD_Data* data, SSERV_Info* info)
 extern "C" {
     static int s_ParseHeader(const char*, void*, int);
 }
-#endif /* __cplusplus */
+#endif /*__cplusplus*/
 
 static int/*bool*/ s_ParseHeader(const char* header,
                                  void*       iter,
                                  int         server_error)
 {
-    SERV_Update((SERV_ITER) iter, header, server_error);
+    struct SDISPD_Data* data = (struct SDISPD_Data*)((SERV_ITER) iter)->data;
+    int code = 0/*success code if any*/;
+    if (server_error) {
+        if (server_error == 400  ||  server_error == 403)
+            data->fail = 1/*true*/;
+    } else if (sscanf(header, "%*s %d", &code) < 1) {
+        data->eof = 1/*true*/;
+        return 0/*header parse error*/;
+    }
+    /* check for empty document */
+    if (!SERV_Update((SERV_ITER) iter, header, server_error)  ||  code == 204)
+        data->eof = 1/*true*/;
     return 1/*header parsed okay*/;
 }
 
@@ -126,30 +139,31 @@ static int/*bool*/ s_ParseHeader(const char* header,
 extern "C" {
     static int s_Adjust(SConnNetInfo*, void*, unsigned int);
 }
-#endif /* __cplusplus */
+#endif /*__cplusplus*/
 
 /*ARGSUSED*/
-/* This callback is only for services called via direct HTTP */
 static int/*bool*/ s_Adjust(SConnNetInfo* net_info,
                             void*         iter,
                             unsigned int  n)
 {
     struct SDISPD_Data* data = (struct SDISPD_Data*)((SERV_ITER) iter)->data;
-    return data->disp_fail ? 0/*failed*/ : 1/*try again*/;
+    return data->fail ? 0/*no more tries*/ : 1/*may try again*/;
 }
 
 
-static int/*bool*/ s_Resolve(SERV_ITER iter)
+static void s_Resolve(SERV_ITER iter)
 {
     struct SDISPD_Data* data = (struct SDISPD_Data*) iter->data;
     SConnNetInfo* net_info = data->net_info;
+    EIO_Status status = eIO_Success;
     CONNECTOR conn = 0;
     char* s;
     CONN c;
 
+    assert(!(data->eof | data->fail));
     assert(!!net_info->stateless == !!iter->stateless);
     /* Obtain additional header information */
-    if ((!(s = SERV_Print(iter, 0))
+    if ((!(s = SERV_Print(iter, 0, 0))
          ||  ConnNetInfo_OverrideUserHeader(net_info, s))
         &&
         ConnNetInfo_OverrideUserHeader(net_info,
@@ -166,8 +180,6 @@ static int/*bool*/ s_Resolve(SERV_ITER iter)
                                        : !net_info->stateless
                                        ? "Client-Mode: STATEFUL_CAPABLE\r\n"
                                        : "Client-Mode: STATELESS_ONLY\r\n")) {
-        /* all the rest in the net_info structure should be already fine */
-        data->disp_fail = 0;
         conn = HTTP_CreateConnectorEx(net_info, fHCC_SureFlush, s_ParseHeader,
                                       s_Adjust, iter/*data*/, 0/*cleanup*/);
     }
@@ -175,17 +187,17 @@ static int/*bool*/ s_Resolve(SERV_ITER iter)
         ConnNetInfo_DeleteUserHeader(net_info, s);
         free(s);
     }
-    if (!conn  ||  CONN_Create(conn, &c) != eIO_Success) {
-        CORE_LOGF_X(1, eLOG_Error, ("[DISPATCHER]  Unable to create aux. %s",
-                                    conn ? "connection" : "connector"));
+    if (conn  &&  (status = CONN_Create(conn, &c)) == eIO_Success) {
+        /* Send all the HTTP data, then trigger header callback */
+        CONN_Flush(c);
+        CONN_Close(c);
+    } else {
+        CORE_LOGF_X(1, eLOG_Error,
+                    ("[%s]  Unable to create auxiliary HTTP %s: %s",
+                     iter->name, conn ? "connection" : "connector",
+                     IO_StatusStr(conn ? status : eIO_Unknown)));
         assert(0);
-        return 0/*failed*/;
     }
-    /* This will also send all the HTTP data, and trigger header callback */
-    CONN_Flush(c);
-    CONN_Close(c);
-    return data->n_cand != 0  ||
-        (!data->disp_fail  &&  net_info->stateless  &&  net_info->firewall);
 }
 
 
@@ -195,9 +207,8 @@ static int/*bool*/ s_Update(SERV_ITER iter, const char* text, int code)
     struct SDISPD_Data* data = (struct SDISPD_Data*) iter->data;
     int/*bool*/ failure;
 
-    if (code == 400)
-        data->disp_fail = 1;
-    if (strncasecmp(text, server_info, sizeof(server_info) - 1) == 0) {
+    if (strncasecmp(text, server_info, sizeof(server_info) - 1) == 0
+        &&  isdigit((unsigned char) text[sizeof(server_info) - 1])) {
         const char* name;
         SSERV_Info* info;
         unsigned int d1;
@@ -241,21 +252,24 @@ static int/*bool*/ s_Update(SERV_ITER iter, const char* text, int code)
     } else if (((failure = strncasecmp(text, HTTP_DISP_FAILURES,
                                        sizeof(HTTP_DISP_FAILURES) - 1) == 0)
                 ||  strncasecmp(text, HTTP_DISP_MESSAGES,
-                                sizeof(HTTP_DISP_MESSAGES) - 1) == 0)) {
+                                sizeof(HTTP_DISP_MESSAGES) - 1) == 0)  &&
+               isspace((unsigned char) text[sizeof(HTTP_DISP_FAILURES) - 1])) {
         assert(sizeof(HTTP_DISP_FAILURES) == sizeof(HTTP_DISP_MESSAGES));
 #if defined(_DEBUG) && !defined(NDEBUG)
         if (data->net_info->debug_printout) {
             text += sizeof(HTTP_DISP_FAILURES) - 1;
             while (*text  &&  isspace((unsigned char)(*text)))
                 text++;
-            CORE_LOGF_X(2, eLOG_Warning,
-                        ("[DISPATCHER %s]  %s",
-                         failure ? "FAILURE" : "MESSAGE", text));
+            CORE_LOGF_X(2, failure ? eLOG_Warning : eLOG_Note,
+                        ("[%s]  %s", data->net_info->service, text));
         }
 #endif /*_DEBUG && !NDEBUG*/
-        if (failure)
-            data->disp_fail = 1;
-        return 1/*updated*/;
+        if (failure) {
+            if (code)
+                data->fail = 1;
+            return 1/*updated*/;
+        }
+        /* NB: a mere message does not constitute an update */
     }
 
     return 0/*not updated*/;
@@ -303,9 +317,15 @@ static SSERV_Info* s_GetNextInfo(SERV_ITER iter, HOST_INFO* host_info)
     size_t n;
 
     assert(data);
-    if (s_IsUpdateNeeded(iter->time, data)  &&
-        (!s_Resolve(iter)  ||  !data->n_cand)) {
-        return 0;
+    if (!data->fail  &&  iter->n_skip < data->n_skip)
+        data->eof = 0/*false*/;
+    data->n_skip = iter->n_skip;
+
+    if (s_IsUpdateNeeded(iter->time, data)) {
+        if (!(data->eof | data->fail))
+            s_Resolve(iter);
+        if (!data->n_cand)
+            return 0;
     }
 
     for (n = 0; n < data->n_cand; n++)
@@ -320,6 +340,7 @@ static SSERV_Info* s_GetNextInfo(SERV_ITER iter, HOST_INFO* host_info)
 
     if (host_info)
         *host_info = 0;
+    data->n_skip++;
 
     return info;
 }
@@ -328,12 +349,16 @@ static SSERV_Info* s_GetNextInfo(SERV_ITER iter, HOST_INFO* host_info)
 static void s_Reset(SERV_ITER iter)
 {
     struct SDISPD_Data* data = (struct SDISPD_Data*) iter->data;
-    if (data  &&  data->cand) {
-        size_t i;
-        assert(data->a_cand);
-        for (i = 0; i < data->n_cand; i++)
-            free((void*) data->cand[i].info);
-        data->n_cand = 0;
+    if (data) {
+        data->eof = data->fail = 0/*false*/;
+        if (data->cand) {
+            size_t i;
+            assert(data->a_cand);
+            for (i = 0; i < data->n_cand; i++)
+                free((void*) data->cand[i].info);
+            data->n_cand = 0;
+        }
+        data->n_skip = iter->n_skip;
     }
 }
 
@@ -341,7 +366,7 @@ static void s_Reset(SERV_ITER iter)
 static void s_Close(SERV_ITER iter)
 {
     struct SDISPD_Data* data = (struct SDISPD_Data*) iter->data;
-    assert(!data->n_cand); /* s_Reset() had to be called before */
+    assert(!data->n_cand); /*s_Reset() had to be called before*/
     if (data->cand)
         free(data->cand);
     ConnNetInfo_Destroy(data->net_info);
@@ -366,15 +391,20 @@ const SSERV_VTable* SERV_DISPD_Open(SERV_ITER iter,
 
     if (!(data = (struct SDISPD_Data*) calloc(1, sizeof(*data))))
         return 0;
+    iter->data = data;
 
-    assert(net_info); /*must called with non-NULL*/
-    if ((data->net_info = ConnNetInfo_Clone(net_info)) != 0)
-        data->net_info->service = iter->name; /* SetupStandardArgs() expects */
-    if (!ConnNetInfo_SetupStandardArgs(data->net_info)) {
-        ConnNetInfo_Destroy(data->net_info);
-        free(data);
+    assert(net_info); /*must be called with non-NULL*/
+    data->net_info = ConnNetInfo_Clone(net_info);
+    if (!ConnNetInfo_SetupStandardArgs(data->net_info, iter->name)) {
+        s_Close(iter);
         return 0;
     }
+
+    if (g_NCBI_ConnectRandomSeed == 0) {
+        g_NCBI_ConnectRandomSeed = iter->time ^ NCBI_CONNECT_SRAND_ADDEND;
+        srand(g_NCBI_ConnectRandomSeed);
+    }
+
     /* Reset request method to be GET ('cause no HTTP body is ever used) */
     data->net_info->req_method = eReqMethod_Get;
     if (iter->stateless)
@@ -390,16 +420,15 @@ const SSERV_VTable* SERV_DISPD_Open(SERV_ITER iter,
                                  " (C Toolkit)"
 #endif /*NCBI_CXX_TOOLKIT*/
                                  "\r\n");
-    iter->data = data;
-    iter->op = &s_op; /* SERV_Update() - from HTTP callback - expects this */
+    data->n_skip = iter->n_skip;
 
-    if (g_NCBI_ConnectRandomSeed == 0) {
-        g_NCBI_ConnectRandomSeed = iter->time ^ NCBI_CONNECT_SRAND_ADDEND;
-        srand(g_NCBI_ConnectRandomSeed);
-    }
+    iter->op = &s_op; /*SERV_Update() [from HTTP callback] expects*/
+    s_Resolve(iter);
+    iter->op = 0;
 
-    if (!s_Resolve(iter)) {
-        iter->op = 0;
+    if (!data->n_cand  &&  (data->fail
+                            ||  !(data->net_info->stateless  &&
+                                  data->net_info->firewall))) {
         s_Reset(iter);
         s_Close(iter);
         return 0;
