@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_SERVER_INFO__H
 #define CONNECT___NCBI_SERVER_INFO__H
 
-/*  $Id: ncbi_server_info.h,v 6.41 2007/02/20 21:25:44 kazimird Exp $
+/*  $Id: ncbi_server_info.h,v 6.44 2008/03/19 23:55:42 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -56,13 +56,13 @@ extern "C" {
 /* Server types
  */
 typedef enum {
-    fSERV_Ncbid           = 0x01,
-    fSERV_Standalone      = 0x02,
-    fSERV_HttpGet         = 0x04,
-    fSERV_HttpPost        = 0x08,
-    fSERV_Http            = fSERV_HttpGet | fSERV_HttpPost,
-    fSERV_Firewall        = 0x10,
-    fSERV_Dns             = 0x20
+    fSERV_Ncbid      = 0x01,
+    fSERV_Standalone = 0x02,
+    fSERV_HttpGet    = 0x04,
+    fSERV_HttpPost   = 0x08,
+    fSERV_Http       = fSERV_HttpGet | fSERV_HttpPost,
+    fSERV_Firewall   = 0x10,
+    fSERV_Dns        = 0x20
 } ESERV_Type;
 
 
@@ -74,10 +74,7 @@ typedef enum {
     fSERV_Blast   = 0x1
 } ESERV_Flag;
 
-
-#define SERV_DEFAULT_FLAG           fSERV_Regular
-#define SERV_MIME_TYPE_UNDEFINED    ((EMIME_Type)(-1))
-#define SERV_MIME_SUBTYPE_UNDEFINED ((EMIME_SubType)(-1))
+#define SERV_DEFAULT_FLAG  fSERV_Regular
                                  
 
 /* Verbal representation of a server type (no internal spaces allowed)
@@ -385,146 +382,4 @@ extern NCBI_XCONNECT_EXPORT int/*bool*/ SERV_EqualInfo
 
 /* @} */
 
-
-/*
- * --------------------------------------------------------------------------
- * $Log: ncbi_server_info.h,v $
- * Revision 6.41  2007/02/20 21:25:44  kazimird
- * Synchronized with the C++ Toolkit.
- *
- * Revision 6.40  2006/03/04 17:02:14  lavr
- * NCBI_TIME_INFINITE moved to ncbi_types.h
- *
- * Revision 6.39  2005/12/23 18:06:53  lavr
- * fSERV_StatelessOnly -> fSERV_Stateless
- * fSERV_Any, fSERV_Stateless -> <connect/ncbi_service.h>
- * +SERV_TIME_INFINITE
- *
- * Revision 6.38  2005/12/14 21:20:59  lavr
- * +SERV_CopyInfo(); DNS type to have name presence flag
- *
- * Revision 6.37  2003/04/09 19:05:48  siyan
- * Added doxygen support
- *
- * Revision 6.36  2003/01/08 01:59:33  lavr
- * DLL-ize CONNECT library for MSVC (add NCBI_XCONNECT_EXPORT)
- *
- * Revision 6.35  2002/11/01 20:10:40  lavr
- * Note that FIREWALL server specs cannot have Q flag set
- *
- * Revision 6.34  2002/09/19 18:04:48  lavr
- * Header file guard macro changed
- *
- * Revision 6.34  2002/09/19 18:01:24  lavr
- * Header file guard macro changed; log moved to the end
- *
- * Revision 6.33  2002/09/17 15:39:07  lavr
- * SSERV_Info::quorum moved past the reserved area
- *
- * Revision 6.32  2002/09/16 14:59:04  lavr
- * Rename SSERV_DnsInfo to follow naming convention for other Info's
- *
- * Revision 6.31  2002/09/04 15:09:17  lavr
- * Add quorum field to SSERV_Info::, log moved to end
- *
- * Revision 6.31  2002/08/16 17:52:27  lavr
- * PUBSYNC, PUBSEEK* macros; SEEKOFF obsoleted; some formatting done
- *
- * Revision 6.30  2002/03/19 22:10:59  lavr
- * Better description for flags 'P' and 'C'
- *
- * Revision 6.29  2002/03/11 21:51:18  lavr
- * Modified server info to include MIME encoding and to prepare for
- * BLAST dispatching to be phased out. Also, new DNS server type defined.
- *
- * Revision 6.28  2001/09/25 14:47:49  lavr
- * TSERV_Flags reverted to 'int'
- *
- * Revision 6.27  2001/09/24 20:22:31  lavr
- * TSERV_Flags changed from 'int' to 'unsigned int'
- *
- * Revision 6.26  2001/09/19 15:57:27  lavr
- * Server descriptor flag "L=" documented more precisely
- *
- * Revision 6.25  2001/09/10 21:16:27  lavr
- * FIREWALL server type added, documented
- *
- * Revision 6.24  2001/06/19 19:09:35  lavr
- * Type change: size_t -> TNCBI_Size; time_t -> TNCBI_Time
- *
- * Revision 6.23  2001/06/12 20:45:23  lavr
- * Less ambiguous comment for SSERV_Info::time
- *
- * Revision 6.22  2001/06/05 14:10:20  lavr
- * SERV_MIME_UNDEFINED split into 2 (typed) constants:
- * SERV_MIME_TYPE_UNDEFINED and SERV_MIME_SUBTYPE_UNDEFINED
- *
- * Revision 6.21  2001/06/04 16:59:56  lavr
- * MIME type/subtype added to server descriptor
- *
- * Revision 6.20  2001/05/17 14:49:46  lavr
- * Typos corrected
- *
- * Revision 6.19  2001/05/03 16:35:34  lavr
- * Local bonus coefficient modified: meaning of negative value changed
- *
- * Revision 6.18  2001/04/24 21:24:05  lavr
- * New server attributes added: locality and bonus coefficient
- *
- * Revision 6.17  2001/03/06 23:52:57  lavr
- * SERV_ReadInfo can now consume either hostname or IP address
- *
- * Revision 6.16  2001/03/05 23:09:20  lavr
- * SERV_WriteInfo & SERV_ReadInfo both take only one argument now
- *
- * Revision 6.15  2001/03/02 20:06:26  lavr
- * Typos fixed
- *
- * Revision 6.14  2001/03/01 18:47:45  lavr
- * Verbal representation of server info is wordly documented
- *
- * Revision 6.13  2000/12/29 17:39:42  lavr
- * Pretty printed
- *
- * Revision 6.12  2000/12/06 22:17:02  lavr
- * Binary host addresses are now explicitly stated to be in network byte
- * order, whereas binary port addresses now use native (host) representation
- *
- * Revision 6.11  2000/10/20 17:05:48  lavr
- * TSERV_Type made 'unsigned int'
- *
- * Revision 6.10  2000/10/05 21:25:45  lavr
- * ncbiconf.h removed
- *
- * Revision 6.9  2000/10/05 21:10:11  lavr
- * ncbiconf.h included
- *
- * Revision 6.8  2000/05/31 23:12:14  lavr
- * First try to assemble things together to get working service mapper
- *
- * Revision 6.7  2000/05/23 19:02:47  lavr
- * Server-info now includes rate; verbal representation changed
- *
- * Revision 6.6  2000/05/22 16:53:07  lavr
- * Rename service_info -> server_info everywhere (including
- * file names) as the latter name is more relevant
- *
- * Revision 6.5  2000/05/15 19:06:05  lavr
- * Use home-made ANSI extensions (NCBI_***)
- *
- * Revision 6.4  2000/05/12 21:42:11  lavr
- * SSERV_Info::  use ESERV_Type, ESERV_Flags instead of TSERV_Type, TSERV_Flags
- *
- * Revision 6.3  2000/05/12 18:31:48  lavr
- * First working revision
- *
- * Revision 6.2  2000/05/09 15:31:29  lavr
- * Minor changes
- *
- * Revision 6.1  2000/05/05 20:24:00  lavr
- * Initial revision
- *
- * ==========================================================================
- */
-
 #endif /* CONNECT___NCBI_SERVER_INFO__H */
