@@ -1,4 +1,4 @@
-/* $Id: ncbi_util.c,v 6.42 2007/07/31 16:25:29 kazimird Exp $
+/* $Id: ncbi_util.c,v 6.59 2009/02/06 16:14:36 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -47,7 +47,7 @@
 #  ifndef NCBI_OS_SOLARIS
 #    include <limits.h>
 #  endif
-#  if defined(HAVE_GETPWUID)  ||  defined(HAVE_GETPWUID_R)
+#  if defined(HAVE_GETPWUID)  ||  defined(NCBI_HAVE_GETPWUID_R)
 #    include <pwd.h>
 #  endif
 #  include <unistd.h>
@@ -58,6 +58,8 @@
 #  include <windows.h>
 #endif
 
+#define NCBI_USE_ERRCODE_X   Connect_Util
+
 #define NCBI_USE_PRECOMPILED_CRC32_TABLES 1
 
 
@@ -77,10 +79,11 @@ extern "C" {
 
 extern void CORE_SetLOCK(MT_LOCK lk)
 {
-    if (g_CORE_MT_Lock  &&  lk != g_CORE_MT_Lock) {
-        MT_LOCK_Delete(g_CORE_MT_Lock);
-    }
+    MT_LOCK old_lk = g_CORE_MT_Lock;
     g_CORE_MT_Lock = lk;
+    if (old_lk  &&  old_lk != lk) {
+        MT_LOCK_Delete(old_lk);
+    }
 }
 
 
@@ -98,12 +101,14 @@ extern MT_LOCK CORE_GetLOCK(void)
 
 extern void CORE_SetLOG(LOG lg)
 {
+    LOG old_lg;
     CORE_LOCK_WRITE;
-    if (g_CORE_Log  &&  lg != g_CORE_Log) {
-        LOG_Delete(g_CORE_Log);
-    }
+    old_lg = g_CORE_Log;
     g_CORE_Log = lg;
     CORE_UNLOCK;
+    if (old_lg  &&  old_lg != lg) {
+        LOG_Delete(old_lg);
+    }
 }
 
 
@@ -129,7 +134,7 @@ extern void CORE_SetLOGFILE
 (FILE*       fp,
  int/*bool*/ auto_close)
 {
-    CORE_SetLOGFILE_Ex(fp, 0, auto_close);
+    CORE_SetLOGFILE_Ex(fp, eLOG_Trace, auto_close);
 }
 
 
@@ -138,8 +143,9 @@ extern int/*bool*/ CORE_SetLOGFILE_NAME_Ex
  ELOG_Level  cut_off)
 {
     FILE* fp = fopen(filename, "a");
-    if ( !fp ) {
-        CORE_LOGF_ERRNO(eLOG_Error, errno, ("Cannot open \"%s\"", filename));
+    if (!fp) {
+        CORE_LOGF_ERRNO_X(9, eLOG_Error, errno,
+                          ("Cannot open \"%s\"", filename));
         return 0/*false*/;
     }
 
@@ -152,7 +158,7 @@ extern int/*bool*/ CORE_SetLOGFILE_NAME
 (const char* filename
  )
 {
-    return CORE_SetLOGFILE_NAME_Ex(filename, 0);
+    return CORE_SetLOGFILE_NAME_Ex(filename, eLOG_Trace);
 }
 
 
@@ -172,13 +178,171 @@ inline
 #endif /*__GNUC__*/
 static int/*bool*/ s_IsQuoted(unsigned char c)
 {
-    return (c == '\t'  ||   c == '\v'  ||  c == '\b'  ||
-            c == '\r'  ||   c == '\f'  ||  c == '\a'  ||
-            c == '\n'  ||   c == '\\'  ||  c == '\''  ||
+    return (c == '\t'  ||  c == '\v'  ||  c == '\b'  ||
+            c == '\r'  ||  c == '\f'  ||  c == '\a'  ||
+            c == '\n'  ||  c == '\\'  ||  c == '\''  ||
             c == '"' ? 1/*true*/ : 0/*false*/);
 }
 
 
+extern size_t UTIL_PrintableStringSize(const char* data, size_t size)
+{
+    const unsigned char* c;
+    size_t retval;
+    if (!data)
+        return 0;
+    if (!size)
+        size = strlen(data);
+    retval = size;
+    for (c = (const unsigned char*) data;  size;  size--, c++) {
+        if (*c == '\n')
+            retval += 3;
+        else if (s_IsQuoted(*c))
+            retval++;
+        else if (!isprint(*c))
+            retval += 3;
+    }
+    return retval;
+}
+
+
+extern char* UTIL_PrintableString(const char* data, size_t size,
+                                  char* buf, int/*bool*/ full_octal)
+{
+    const unsigned char* s;
+    unsigned char* d;
+
+    if (!data  ||  !buf)
+        return 0;
+    if (!size)
+        size = strlen(data);
+
+    d = (unsigned char*) buf;
+    for (s = (const unsigned char*) data;  size;  size--, s++) {
+        switch (*s) {
+        case '\t':
+            *d++ = '\\';
+            *d++ = 't';
+            continue;
+        case '\v':
+            *d++ = '\\';
+            *d++ = 'v';
+            continue;
+        case '\b':
+            *d++ = '\\';
+            *d++ = 'b';
+            continue;
+        case '\r':
+            *d++ = '\\';
+            *d++ = 'r';
+            continue;
+        case '\f':
+            *d++ = '\\';
+            *d++ = 'f';
+            continue;
+        case '\a':
+            *d++ = '\\';
+            *d++ = 'a';
+            continue;
+        case '\n':
+            *d++ = '\\';
+            *d++ = 'n';
+            /*FALLTHRU*/
+        case '\\':
+        case '\'':
+        case '"':
+            *d++ = '\\';
+            break;
+        default:
+            if (!isprint(*s)) {
+                int/*bool*/ reduce;
+                unsigned char v;
+                if (full_octal)
+                    reduce = 0/*false*/;
+                else {
+                    reduce = (size == 1       ||  s_IsQuoted(s[1])  ||
+                              !isprint(s[1])  ||  s[1] < '0'  ||  s[1] > '7');
+                }
+                *d++ = '\\';
+                v =  *s >> 6;
+                if (v  ||  !reduce) {
+                    *d++ = '0' + v;
+                    reduce = 0;
+                }
+                v = (*s >> 3) & 7;
+                if (v  ||  !reduce)
+                    *d++ = '0' + v;
+                v =  *s & 7;
+                *d++ =     '0' + v;
+                continue;
+            }
+            break;
+        }
+        *d++ = (char) *s;
+    }
+
+    return (char*) d;
+}
+
+
+extern const char* NcbiMessagePlusError
+(int/*bool*/ *dynamic,
+ const char*  message,
+ int          error,
+ const char*  descr)
+{
+    char*  buf;
+    size_t mlen;
+    size_t dlen;
+
+    /* Check for an empty addition */
+    if (!error  &&  (!descr  ||  !*descr)) {
+        if (message)
+            return message;
+        *dynamic = 0/*false*/;
+        return "";
+    }
+
+    /* Adjust description, if necessary and possible */
+    if (error  &&  !descr) {
+        if (error < 0  ||  !(descr = strerror(error)))
+            descr = "";
+    }
+    dlen = strlen(descr);
+    while (dlen  &&  isspace((unsigned char) descr[dlen - 1]))
+        dlen--;
+    if (dlen > 1  &&  descr[dlen - 1] == '.')
+        dlen--;
+
+    mlen = message ? strlen(message) : 0;
+
+    if (!(buf = (char*)(*dynamic  &&  message
+                        ? realloc((void*) message, mlen + dlen + 40)
+                        : malloc (                 mlen + dlen + 40)))) {
+        if (*dynamic  &&  message)
+            free((void*) message);
+        *dynamic = 0;
+        return "<Ouch! Out of memory>";
+    }
+
+    if (message) {
+        if (!*dynamic)
+            memcpy(buf, message, mlen);
+        buf[mlen++] = ' ';
+    }
+    memcpy(buf + mlen, "{error=", 7);
+    mlen += 7;
+
+    if (error)
+        mlen += sprintf(buf + mlen, "%d%s", error, "," + !*descr);
+
+    memcpy((char*) memcpy(buf + mlen, descr, dlen) + dlen, "}", 2);
+
+    *dynamic = 1/*true*/;
+    return buf;
+}
+
+
 extern char* LOG_ComposeMessage
 (const SLOG_Handler* call_data,
  TLOG_FormatFlags    format_flags)
@@ -226,7 +390,7 @@ extern char* LOG_ComposeMessage
         datetime[datetime_len++] = ' ';
         datetime[datetime_len]   = '\0';
 #else /*NCBI_OS_MSWIN*/
-        static const char timefmt[] = "%D %T ";
+        static const char timefmt[] = "%m/%d/%y %H:%M:%S ";
         struct tm* tm;
 #  ifdef NCBI_CXX_TOOLKIT
         time_t t = time(0);
@@ -263,18 +427,11 @@ extern char* LOG_ComposeMessage
         message_len = strlen(call_data->message);
     }
 
-    if ( call_data->raw_size ) {
-        const unsigned char* d = (const unsigned char*) call_data->raw_data;
-        size_t i = call_data->raw_size;
-        for (data_len = 0;  i;  i--, d++) {
-            if (s_IsQuoted(*d)) {
-                data_len++;
-            } else if (!isprint(*d)) {
-                data_len += 3;
-            }
-        }
-        data_len += (sizeof(kRawData_Begin) + 20 + call_data->raw_size +
-                     sizeof(kRawData_End));
+    if (call_data->raw_size) {
+        data_len = (sizeof(kRawData_Begin) + 20
+                    + UTIL_PrintableStringSize(call_data->raw_data,
+                                               call_data->raw_size) +
+                    sizeof(kRawData_End));
     }
 
     /* Allocate memory for the resulting message */
@@ -287,94 +444,39 @@ extern char* LOG_ComposeMessage
 
     s = str;
     /* Compose the message */
-    if ( datetime_len ) {
+    if (datetime_len) {
         memcpy(s, datetime, datetime_len);
         s += datetime_len;
     }
-    if ( file_line_len ) {
+    if (file_line_len) {
         s += sprintf(s, "\"%s\", line %d: ",
                      call_data->file, (int) call_data->line);
     }
-    if ( module_len ) {
+    if (module_len) {
         *s++ = '[';
         memcpy(s, call_data->module, module_len -= 3);
         s += module_len;
         *s++ = ']';
         *s++ = ' ';
     }
-    if ( level_len ) {
+    if (level_len) {
         memcpy(s, level, level_len -= 2);
         s += level_len;
         *s++ = ':';
         *s++ = ' ';
     }
-    if ( message_len ) {
+    if (message_len) {
         memcpy(s, call_data->message, message_len);
         s += message_len;
     }
-    if ( data_len ) {
-        const unsigned char* d;
-        size_t i;
-
-        s += sprintf(s, kRawData_Begin, (unsigned long) call_data->raw_size,
+    if (data_len) {
+        s += sprintf(s, kRawData_Begin,
+                     (unsigned long) call_data->raw_size,
                      &"s"[call_data->raw_size == 1]);
 
-        d = (const unsigned char*) call_data->raw_data;
-        for (i = call_data->raw_size;  i;  i--, d++) {
-            switch (*d) {
-            case '\t':
-                *s++ = '\\';
-                *s++ = 't';
-                continue;
-            case '\v':
-                *s++ = '\\';
-                *s++ = 'v';
-                continue;
-            case '\b':
-                *s++ = '\\';
-                *s++ = 'b';
-                continue;
-            case '\r':
-                *s++ = '\\';
-                *s++ = 'r';
-                continue;
-            case '\f':
-                *s++ = '\\';
-                *s++ = 'f';
-                continue;
-            case '\a':
-                *s++ = '\\';
-                *s++ = 'a';
-                continue;
-            case '\n':
-            case '\\':
-            case '\'':
-            case '"':
-                *s++ = '\\';
-                break;
-            default:
-                if (!isprint(*d)) {
-                    int/*bool*/ reduce;
-                    unsigned char v;
-                    reduce = (i == 1          ||  s_IsQuoted(d[1])  ||
-                              !isprint(d[1])  ||  d[1] < '0'  ||  d[1] > '7');
-                    *s++ = '\\';
-                    v =  *d >> 6;
-                    if (v  ||  !reduce) {
-                        *s++ = '0' + v;
-                        reduce = 0;
-                    }
-                    v = (*d >> 3) & 7;
-                    if (v  ||  !reduce)
-                        *s++ = '0' + v;
-                    v =  *d & 7;
-                    *s++ =     '0' + v;
-                    continue;
-                }
-                break;
-            }
-            *s++ = (char) *d;
-        }
+        s = UTIL_PrintableString(call_data->raw_data,
+                                 call_data->raw_size,
+                                 s, format_flags & fLOG_FullOctal);
 
         memcpy(s, kRawData_End, sizeof(kRawData_End));
     } else
@@ -401,7 +503,7 @@ static void s_LOG_FileHandler(void* user_data, SLOG_Handler* call_data)
 
     if (call_data->level >= data->cut_off  ||  call_data->level == eLOG_Fatal){
         char* str = LOG_ComposeMessage(call_data, s_LogFormatFlags);
-        if ( str ) {
+        if (str) {
             fprintf(data->fp, "%s\n", str);
             fflush(data->fp);
             free(str);
@@ -432,7 +534,7 @@ extern void LOG_ToFILE_Ex
  )
 {
     SLogData* data = (SLogData*)(fp ? malloc(sizeof(*data)) : 0);
-    if ( data ) {
+    if (data) {
         data->fp         = fp;
         data->cut_off    = cut_off;
         data->auto_close = auto_close;
@@ -449,123 +551,7 @@ extern void LOG_ToFILE
  int/*bool*/ auto_close
  )
 {
-    LOG_ToFILE_Ex(lg, fp, 0, auto_close);
-}
-
-
-/* Return non-zero value if "*beg" has reached the "end"
- */
-static int/*bool*/ s_SafeCopy(const char* src, char** beg, const char* end)
-{
-    assert(*beg <= end);
-    if ( src ) {
-        for ( ;  *src  &&  *beg != end;  src++, (*beg)++) {
-            **beg = *src;
-        }
-    }
-    **beg = '\0';
-    return (*beg == end);
-}
-
-
-extern char* MessagePlusErrno
-(const char*  message,
- int          x_errno,
- const char*  descr,
- char*        buf,
- size_t       buf_size)
-{
-    char* beg;
-    char* end;
-
-    /* Check and init */
-    if (!buf  ||  !buf_size)
-        return 0;
-    buf[0] = '\0';
-    if (buf_size < 2)
-        return buf;  /* empty */
-
-    /* Adjust the description, if necessary and possible */
-    if (x_errno  &&  !descr) {
-        descr = strerror(x_errno);
-        if ( !descr ) {
-            static const char s_UnknownErrno[] = "Error code is out of range";
-            descr = s_UnknownErrno;
-        }
-    }
-
-    /* Check for an empty result, calculate string lengths */
-    if ((!message  ||  !*message)  &&  !x_errno  &&  (!descr  ||  !*descr))
-        return buf;  /* empty */
-
-    /* Compose:   <message> {errno=<x_errno>,<descr>} */
-    beg = buf;
-    end = buf + buf_size - 1;
-
-    /* <message> */
-    if ( s_SafeCopy(message, &beg, end) )
-        return buf;
-
-    /* {errno=<x_errno>,<descr>} */
-    if (!x_errno  &&  (!descr  ||  !*descr))
-        return buf;
-
-    /* "{errno=" */
-    if ( s_SafeCopy(" {errno=", &beg, end) )
-        return buf;
-
-    /* <x_errno> */
-    if ( x_errno ) {
-        int/*bool*/ neg;
-        /* calculate length */
-        size_t len;
-        int    mod;
-
-        if (x_errno < 0) {
-            neg = 1/*true*/;
-            x_errno = -x_errno;
-        } else {
-            neg = 0/*false*/;
-        }
-
-        for (len = 1, mod = 1;  (x_errno / mod) > 9;  len++, mod *= 10)
-            continue;
-        if ( neg )
-            len++;
-
-        /* ? not enough space */
-        if (beg + len >= end) {
-            s_SafeCopy("...", &beg, end);
-            return buf;
-        }
-
-        /* ? add sign */ 
-        if (x_errno < 0) {
-            *beg++ = '-';
-        }
-
-        /* print error code */
-        for ( ;  mod;  mod /= 10) {
-            assert(x_errno / mod < 10);
-            *beg++ = '0' + x_errno / mod;
-            x_errno %= mod;
-        }
-        /* "," before "<descr>" */
-        if (descr  &&  *descr  &&  beg != end)
-            *beg++ = ',';
-    }
-
-    /* "<descr>" */
-    if ( s_SafeCopy(descr, &beg, end) )
-        return buf;
-
-    /* "}\0" */
-    assert(beg <= end);
-    if (beg != end)
-        *beg++ = '}';
-    *beg = '\0';
-
-    return buf;
+    LOG_ToFILE_Ex(lg, fp, eLOG_Trace, auto_close);
 }
 
 
@@ -576,12 +562,14 @@ extern char* MessagePlusErrno
 
 extern void CORE_SetREG(REG rg)
 {
+    REG old_rg;
     CORE_LOCK_WRITE;
-    if (g_CORE_Registry  &&  rg != g_CORE_Registry) {
-        REG_Delete(g_CORE_Registry);
-    }
+    old_rg = g_CORE_Registry;
     g_CORE_Registry = rg;
     CORE_UNLOCK;
+    if (old_rg  &&  old_rg != rg) {
+        REG_Delete(old_rg);
+    }
 }
 
 
@@ -625,7 +613,7 @@ extern const char* CORE_GetUsername(char* buf, size_t bufsize)
     char loginbuf[LOGIN_NAME_MAX + 1];
 #  endif
     struct passwd* pw;
-#  if !defined(NCBI_OS_SOLARIS)  &&  defined(HAVE_GETPWUID_R)
+#  if !defined(NCBI_OS_SOLARIS)  &&  defined(NCBI_HAVE_GETPWUID_R)
     struct passwd pwd;
     char pwdbuf[256];
 #  endif
@@ -677,7 +665,7 @@ extern const char* CORE_GetUsername(char* buf, size_t bufsize)
 #  endif
 
 #  if defined(NCBI_OS_SOLARIS)  ||  \
-    (!defined(HAVE_GETPWUID_R)  &&  defined(HAVE_GETPWUID))
+    (!defined(NCBI_HAVE_GETPWUID_R)  &&  defined(HAVE_GETPWUID))
     /* NB:  getpwuid() is MT-safe on Solaris, so use it here, if available */
 #  ifndef NCBI_OS_SOLARIS
     CORE_LOCK_WRITE;
@@ -689,23 +677,23 @@ extern const char* CORE_GetUsername(char* buf, size_t bufsize)
 #  endif
     if (pw  &&  pw->pw_name)
         return buf;
-#  elif defined(HAVE_GETPWUID_R)
-#    if   HAVE_GETPWUID_R == 4
+#  elif defined(NCBI_HAVE_GETPWUID_R)
+#    if   NCBI_HAVE_GETPWUID_R == 4
     /* obsolete but still existent */
     pw = getpwuid_r(getuid(), &pwd, pwdbuf, sizeof(pwdbuf));
-#    elif HAVE_GETPWUID_R == 5
+#    elif NCBI_HAVE_GETPWUID_R == 5
     /* POSIX-conforming */
     if (getpwuid_r(getuid(), &pwd, pwdbuf, sizeof(pwdbuf), &pw) != 0)
         pw = 0;
 #    else
-#      error "Unknown value of HAVE_GETPWUID_R, 4 or 5 expected."
+#      error "Unknown value of NCBI_HAVE_GETPWUID_R, 4 or 5 expected."
 #    endif
     if (pw  &&  pw->pw_name) {
         assert(pw == &pwd);
         strncpy0(buf, pw->pw_name, bufsize - 1);
         return buf;
     }
-#  endif /*HAVE_GETPWUID_R*/
+#  endif /*NCBI_HAVE_GETPWUID_R*/
 
 #endif /*!NCBI_OS_UNIX*/
 
@@ -774,7 +762,7 @@ size_t CORE_GetVMPageSize(void)
 
 #ifdef NCBI_USE_PRECOMPILED_CRC32_TABLES
 
-static const unsigned int s_CRC32[256] = {
+static const unsigned int s_CRC32Table[256] = {
     0x00000000, 0x04c11db7, 0x09823b6e, 0x0d4326d9,
     0x130476dc, 0x17c56b6b, 0x1a864db2, 0x1e475005,
     0x2608edb8, 0x22c9f00f, 0x2f8ad6d6, 0x2b4bcb61,
@@ -843,13 +831,13 @@ static const unsigned int s_CRC32[256] = {
 
 #else
 
-static unsigned int s_CRC32[256];
+static unsigned int s_CRC32Table[256];
 
 static void s_CRC32_Init(void)
 {
     size_t i;
 
-    if (s_CRC32[255])
+    if (s_CRC32Table[255])
         return;
 
     for (i = 0;  i < 256;  i++) {
@@ -862,7 +850,7 @@ static void s_CRC32_Init(void)
             } else
                 byteCRC <<= 1;
         }
-        s_CRC32[i] = byteCRC;
+        s_CRC32Table[i] = byteCRC;
     }
 }
 
@@ -882,7 +870,7 @@ extern unsigned int CRC32_Update(unsigned int checksum,
     for (j = 0;  j < count;  j++) {
         size_t i = ((checksum >> 24) ^ *str++) & 0xFF;
         checksum <<= 8;
-        checksum  ^= s_CRC32[i];
+        checksum  ^= s_CRC32Table[i];
     }
 
     return checksum;
@@ -935,3 +923,31 @@ extern int/*bool*/ UTIL_MatchesMask(const char* name, const char* mask)
 {
     return UTIL_MatchesMaskEx(name, mask, 1/*ignore case*/);
 }
+
+
+extern char* UTIL_NcbiLocalHostName(char* hostname)
+{
+    static const struct {
+        const char* text;
+        size_t      len;
+    } kEndings[] = {
+        { ".ncbi.nlm.nih.gov", 17},
+        { ".ncbi.nih.gov", 13}
+    };
+    size_t len = hostname ? strlen(hostname) : 0;
+
+    if (len) {
+        size_t i;
+        for (i = 0;  i < sizeof(kEndings) / sizeof(kEndings[0]);  i++) {
+            assert(strlen(kEndings[i].text) == kEndings[i].len);
+            if (len > kEndings[i].len) {
+                size_t prefix = len - kEndings[i].len;
+                if (strcasecmp(hostname + prefix, kEndings[i].text) == 0) {
+                    hostname[prefix] = '\0';
+                    return hostname;
+                }
+            }
+        }
+    }
+    return 0;
+}
