@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_UTIL__H
 #define CONNECT___NCBI_UTIL__H
 
-/*  $Id: ncbi_util.h,v 6.28 2007/07/31 16:25:29 kazimird Exp $
+/* $Id: ncbi_util.h,v 6.38 2008/12/01 16:34:35 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -38,11 +38,12 @@
  *    macros:     LOG_Write(), LOG_Data(),
  *                LOG_WRITE(), LOG_DATA(),
  *                THIS_FILE, THIS_MODULE,
- *                LOG_WRITE_ERRNO_EX(), LOG_WRITE_ERRNO()
  *    flags:      TLOG_FormatFlags, ELOG_FormatFlags
- *    methods:    LOG_ComposeMessage(), LOG_ToFILE(), MessagePlusErrno(),
+ *    methods:    LOG_ComposeMessage(), LOG_ToFILE(), NcbiMessagePlusError(),
  *                CORE_SetLOCK(), CORE_GetLOCK(),
- *                CORE_SetLOG(),  CORE_GetLOG(),   CORE_SetLOGFILE()
+ *                CORE_SetLOG(),  CORE_GetLOG(),
+ *                CORE_SetLOGFILE[_Ex](), CORE_SetLOGFILE_NAME[_Ex]()
+ *                LOG_ToFILE[_Ex]()
  *
  * 2. Auxiliary API:
  *       CORE_GetPlatform()
@@ -54,6 +55,8 @@
  *
  * 4. Miscellaneous:
  *       UTIL_MatchesMask[Ex]()
+ *       UTIL_NcbiLocalHostName()
+ *       UTIL_PrintableString[Size]()
  *
  */
 
@@ -100,34 +103,22 @@ extern NCBI_XCONNECT_EXPORT MT_LOCK CORE_GetLOCK(void);
  */
 
 
-/** Slightly customized LOG_WriteInternal() -- to distinguish between
- * logging only a message vs logging a message with some data.
- * @sa
- *  LOG_WriteInternal
- */
-#define LOG_Write(lg,level,module,file,line,message) \
-  (void) (((lg)  ||  (level) == eLOG_Fatal) ?                         \
-  (LOG_WriteInternal(lg,level,module,file,line,message,0,0), 0) : 1)
-#define LOG_Data(lg,level,module,file,line,data,size,message) \
-  (void) (((lg)  ||  (level) == eLOG_Fatal) ?                         \
-  (LOG_WriteInternal(lg,level,module,file,line,message,data,size), 0) : 1)
-
-
 /** Auxiliary plain macros to write message (maybe, with raw data) to the log.
  * @sa
- *   LOG_Write, LOG_Data
+ *   LOG_Write
  */
-#define  LOG_WRITE(lg, level, message) \
-  LOG_Write(lg, level, THIS_MODULE, THIS_FILE, __LINE__, message)
+#define  LOG_WRITE(lg, code, subcode, level, message)                   \
+    LOG_Write(lg, code, subcode, level, THIS_MODULE, THIS_FILE, __LINE__, \
+              message, 0, 0)
 
 #ifdef   LOG_DATA
 /* AIX's <pthread.h> defines LOG_DATA to be an integer constant;
    we must explicitly drop such definitions to avoid trouble */
 #  undef LOG_DATA
 #endif
-#define  LOG_DATA(lg, data, size, message) \
-  LOG_Data(lg, eLOG_Trace, THIS_MODULE, THIS_FILE, __LINE__, \
-           data, size, message)
+#define  LOG_DATA(lg, code, subcode, level, data, size, message)        \
+    LOG_Write(lg, code, subcode, level, THIS_MODULE, THIS_FILE, __LINE__, \
+              message, data, size)
 
 
 /** Defaults for the THIS_FILE and THIS_MODULE macros (used by LOG_WRITE).
@@ -229,11 +220,12 @@ typedef enum {
     fLOG_Module        = 0x2,
     fLOG_FileLine      = 0x4,    /**< always here for eLOG_Trace level       */
     fLOG_DateTime      = 0x8,
+    fLOG_FullOctal     = 0x2000, /**< do not do reduction in octal data bytes*/
     fLOG_OmitNoteLevel = 0x4000, /**< do not add NOTE if eLOG_Note is level  */
     fLOG_None          = 0x8000  /**< nothing but spec'd parts, msg and data */
 } ELOG_Format;
 typedef unsigned int TLOG_FormatFlags; /**< binary OR of "ELOG_FormatFlags"  */
-#define fLOG_Short  (fLOG_Level)
+#define fLOG_Short   fLOG_Level
 #define fLOG_Full   (fLOG_Level | fLOG_Module | fLOG_FileLine)
 
 extern NCBI_XCONNECT_EXPORT TLOG_FormatFlags CORE_SetLOGFormatFlags
@@ -294,52 +286,63 @@ extern NCBI_XCONNECT_EXPORT void LOG_ToFILE
  );
 
 
-/** Add current "errno" (and maybe its description) to the message:
- * <message> {errno=<errno>,<descr>}
+/** Add current "error" (and maybe its description) to the message:
+ * <message>[ {error=[[<error>][,]][<descr>]}]
+ * @param dynamic
+ *  [inout] non-zero pointed value means message was allocated from heap
  * @param message
- *  [in]  message text (can be NULL)
- * @param x_errno
- *  [in]  error code (if it is zero, then use "descr" only)
+ *  [in]    message text (can be NULL)
+ * @param error
+ *  [in]    error code (if it is zero, then use "descr" only if non-NULL/empty)
  * @param descr
- *  [in]  error description (if NULL, then use "strerror(x_errno)")
- * @param buf
- *  [out] buffer to put the composed message to
- * @param buf_size
- *  [in]  maximal buffer size
+ *  [in]    error description (if NULL, then use "strerror(error)" if error!=0)
  * @return
- *  Return "buf"
+ *  Always non-NULL message (perhaps, "") and re-set "*dynamic" as appropriate.
+ * @li <b>NOTE:</b>  this routine may call "free(message)" if it had
+ * to reallocate the original message that had been allocated dynamically
+ * before the call (and "*dynamic" thus had been passed non-zero).
  * @sa
  *  LOG_ComposeMessage
  */
-extern NCBI_XCONNECT_EXPORT char* MessagePlusErrno
-(const char*  message,
- int          x_errno,
- const char*  descr,
- char*        buf,
- size_t       buf_size
+extern NCBI_XCONNECT_EXPORT const char* NcbiMessagePlusError
+(int*/*bool*/ dynamic,
+ const char*  message,
+ int          error,
+ const char*  descr
  );
 
 
-/** Special log writing macro that makes use of a specified error number,
- * and an optional description thereof.
- * @sa
- *  LOG_WRITE_ERRNO
+/* Several macros brought here from ncbidiag.hpp.  The names slightly
+ * changed (added _C) because some sources can include this header and
+ * ncbidiag.hpp simultaneously.
  */
-#define LOG_WRITE_ERRNO_EX(lg, level, message, x_errno, x_descr)  do {   \
-    if ((lg)  ||  (level) == eLOG_Fatal) {                               \
-        char _buf[1024];                                                 \
-        LOG_WRITE(lg, level, MessagePlusErrno(message, x_errno, x_descr, \
-                                              _buf, sizeof(_buf)));      \
-    }                                                                    \
-} while (0)
 
-
-/** Variant of LOG_WRITE_ERRNO_EX that uses current errno.
- * @sa
- *   LOG_WRITE_ERRNO_EX
+/** Defines global error code name with given value (err_code)
  */
-#define LOG_WRITE_ERRNO(lg, level, message)                              \
-     LOG_WRITE_ERRNO_EX(lg, level, message, errno, 0)
+#define NCBI_C_DEFINE_ERRCODE_X(name, err_code, max_err_subcode)        \
+    enum enum##name {                                                   \
+        eErrCodeX_##name = err_code                                     \
+        /* automatic subcode checking is not implemented in C code */   \
+    }
+
+/** Makes one identifier from 2 parts
+ */
+#define NCBI_C_CONCAT_IDENTIFIER(prefix, postfix) prefix##postfix
+
+/** Returns value of error code by its name defined by NCBI_DEFINE_ERRCODE_X
+ *
+ * @sa NCBI_C_DEFINE_ERRCODE_X
+ */
+#define NCBI_C_ERRCODE_X_NAME(name)   \
+    NCBI_C_CONCAT_IDENTIFIER(eErrCodeX_, name)
+
+/** Returns currently set default error code. Default error code is set by
+ *  definition of NCBI_USE_ERRCODE_X with name of error code as its value.
+ *
+ * @sa NCBI_DEFINE_ERRCODE_X
+ */
+#define NCBI_C_ERRCODE_X   NCBI_C_ERRCODE_X_NAME(NCBI_USE_ERRCODE_X)
+
 
 
 
@@ -452,13 +455,68 @@ extern NCBI_XCONNECT_EXPORT int/*bool*/ UTIL_MatchesMaskEx
  *  TODO!
  * @param mask
  *  TODO!
-*/
+ */
 extern NCBI_XCONNECT_EXPORT int/*bool*/ UTIL_MatchesMask
 (const char* name,
  const char* mask
 );
 
 
+/** Cut off well-known NCBI domain suffix out of the passed "hostname".
+ * @param hostname
+ *  Hostname to shorten (if possible)
+ * @return 0 if the hostname wasn't modified, otherwise return "hostname".
+ */
+extern char* UTIL_NcbiLocalHostName
+(char*       hostname
+ );
+
+
+/** Calculate size of buffer needed to store printable representation of the
+ * block of data of the specified size (or, if size is 0, strlen(data)).
+ * NOTE:  The calculated size does not include terminating '\0'.
+ * @param data
+ *  Block of data (NULL causes 0 to return regardless of "size")
+ * @param size
+ *  Size of block (0 causes strlen(data) to be used)
+ * @return the buffer size needed (0 for NULL or empty (size==0) block).
+ * @sa UTIL_PrintableString
+ */
+extern size_t UTIL_PrintableStringSize
+(const char* data,
+ size_t      size
+ );
+
+
+/** Create printable representation of the block of data of the specified size
+ * (or, if size is 0, strlen(data), and return buffer pointer past the last
+ * stored character (non '\0'-terminated).
+ * NOTE:  The input buffer "buf" where to store the printable representation
+ * is assumed to be of adequate size to hold the resultant string.
+ * Non-printable characters can be represented in a reduced octal form
+ * as long as the result is unambiguous (unless "full" passed true (non-zero),
+ * in which case all non-printable characters get represented by full
+ * octal tetrads).  NB: Hexadecimal output is not used because it is
+ * ambiguous by the standard (can contain undefined number of hex digits).
+ * @param data
+ *  Block of data (NULL causes NULL to return regardless of "size" or "buf")
+ * @param size
+ *  Size of block (0 causes strlen(data) to be used)
+ * @buf
+ *  Buffer to store the result (NULL always causes NULL to return)
+ * @full
+ *  Whether to print full octal representation of non-printable characters
+ * @return next position in the buffer past the last stored character.
+ * @sa UTIL_PrintableStringSize
+ */
+extern char* UTIL_PrintableString
+(const char* data,
+ size_t      size,
+ char*       buf,
+ int         full
+ );
+
+
 #ifdef __cplusplus
 }  /* extern "C" */
 #endif
