@@ -1,4 +1,4 @@
-/*  $Id: test_ncbi_core.c,v 6.13 2007/06/25 16:55:29 kazimird Exp $
+/*  $Id: test_ncbi_core.c,v 6.18 2008/11/28 23:59:43 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -66,14 +66,6 @@ extern "C" {
  *  TEST_CORE -- test "ncbi_core.c"
  */
 
-static void TEST_CORE_Generic(void)
-{
-  /* STimeout */
-  static STimeout x_timeout = { 111111, 222222 };
-  x_timeout.sec  = (unsigned int) 333333;
-  x_timeout.usec = (unsigned int) 444444;
-}
-
 
 static void TEST_CORE_Io(void)
 {
@@ -258,10 +250,10 @@ static void TEST_CORE_Log(void)
   verify(LOG_Delete(x_log) == x_log);
   assert(TEST_CORE_LogUserData == 1);
 
-  LOG_WRITE(0, eLOG_Trace, 0);
-  LOG_Write(0, eLOG_Trace, 0, 0, 0, 0);
-  LOG_WRITE(x_log, eLOG_Trace, 0);
-  LOG_Write(x_log, eLOG_Trace, 0, 0, 0, 0);
+  LOG_WRITE(0, 0, 0, eLOG_Trace, 0);
+  LOG_Write(0, 0, 0, eLOG_Trace, 0, 0, 0, 0, 0, 0);
+  LOG_WRITE(x_log, 0, 0, eLOG_Trace, 0);
+  LOG_Write(x_log, 0, 0, eLOG_Trace, 0, 0, 0, 0, 0, 0);
 
   verify(LOG_Delete(x_log) == x_log);
   assert(TEST_CORE_LogUserData == 1);
@@ -273,16 +265,16 @@ static void TEST_CORE_Log(void)
   TEST_CORE_LogUserData = 2;
 
   /* do the test logging */
-  LOG_WRITE(x_log, eLOG_Trace, 0);
-  LOG_Write(x_log, eLOG_Trace, 0, 0, 0, 0);
-  LOG_WRITE(x_log, eLOG_Warning, "");
+  LOG_WRITE(x_log, 0, 0, eLOG_Trace, 0);
+  LOG_Write(x_log, 0, 0, eLOG_Trace, 0, 0, 0, 0, 0, 0);
+  LOG_WRITE(x_log, 0, 0, eLOG_Warning, "");
   /* LOG_WRITE(x_log, eLOG_Fatal, "Something fatal"); */
 #undef  THIS_MODULE
 #define THIS_MODULE "FooModuleName"
-  LOG_WRITE(x_log, eLOG_Error, "With changed module name");
+  LOG_WRITE(x_log, 0, 0, eLOG_Error, "With changed module name");
 #undef  THIS_FILE
 #define THIS_FILE "BarFileName"
-  LOG_WRITE(x_log, eLOG_Critical, "With changed module and file name");
+  LOG_WRITE(x_log, 0, 0, eLOG_Critical, "With changed module and file name");
 #undef  THIS_FILE
 #define THIS_FILE __FILE__
 #undef  THIS_MODULE
@@ -297,7 +289,6 @@ static void TEST_CORE_Log(void)
 static void TEST_CORE(void)
 {
   /* Do all TEST_CORE_***() tests */
-  DO_TEST(TEST_CORE_Generic);
   DO_TEST(TEST_CORE_Io);
   DO_TEST(TEST_CORE_Lock);
   DO_TEST(TEST_CORE_Log);
@@ -316,16 +307,16 @@ static void TEST_UTIL_Log(void)
   LOG_ToFILE(x_log, stdout, 0/*false*/);
 
   /* simple logging */
-  LOG_WRITE(x_log, eLOG_Trace, 0);
-  LOG_Write(x_log, eLOG_Trace, 0, 0, 0, 0);
-  LOG_WRITE(x_log, eLOG_Warning, "");
+  LOG_WRITE(x_log, 0, 0, eLOG_Trace, 0);
+  LOG_Write(x_log, 0, 0, eLOG_Trace, 0, 0, 0, 0, 0, 0);
+  LOG_WRITE(x_log, 0, 0, eLOG_Warning, "");
   /* LOG_WRITE(x_log, eLOG_Fatal, "Something fatal"); */
 #undef  THIS_MODULE
 #define THIS_MODULE "FooModuleName"
-  LOG_WRITE(x_log, eLOG_Error, "With changed module name");
+  LOG_WRITE(x_log, 0, 0, eLOG_Error, "With changed module name");
 #undef  THIS_FILE
 #define THIS_FILE "BarFileName"
-  LOG_WRITE(x_log, eLOG_Critical, "With changed module and file name");
+  LOG_WRITE(x_log, 0, 0, eLOG_Critical, "With changed module and file name");
 #undef  THIS_FILE
 #define THIS_FILE __FILE__
 #undef  THIS_MODULE
@@ -338,21 +329,9 @@ static void TEST_UTIL_Log(void)
     for (i = 0;  i < sizeof(data);  i++) {
         data[i] = (unsigned char) (i % 256);
     }
-    LOG_DATA(x_log, data, sizeof(data), "Data logging test");
+    LOG_DATA(x_log, 0, 0, eLOG_Note, data, sizeof(data), "Data logging test");
   }}
 
-  /* logging with errno */
-  errno = 0;
-  LOG_WRITE_ERRNO(x_log, eLOG_Warning, 0);  
-  LOG_WRITE_ERRNO(x_log, eLOG_Error, "");
-  LOG_WRITE_ERRNO(x_log, eLOG_Critical, "OKAY");
-
-#undef  THIS_FILE
-#define THIS_FILE 0
-  (void)strtod("1e-999999", 0);  LOG_WRITE_ERRNO(x_log, eLOG_Warning, 0);  
-  (void)strtod("1e-999999", 0);  LOG_WRITE_ERRNO(x_log, eLOG_Error, "");
-  (void)strtod("1e-999999", 0);  LOG_WRITE_ERRNO(x_log, eLOG_Critical, "FAIL");
-
   /* delete */
   verify(LOG_Delete(x_log) == 0);
 }
