@@ -1,4 +1,4 @@
-/*  $Id: test_ncbi_ftp_connector.c,v 1.11 2005/07/22 16:09:15 lavr Exp $
+/* $Id: test_ncbi_ftp_connector.c,v 1.17 2008/10/21 19:25:44 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -33,34 +33,33 @@
 #include "../ncbi_ansi_ext.h"
 #include "../ncbi_priv.h"
 #include <connect/ncbi_connection.h>
+#include <connect/ncbi_connutil.h>
 #include <connect/ncbi_ftp_connector.h>
 #include <stdlib.h>
 #include <time.h>
 /* This header must go last */
 #include "test_assert.h"
 
-
-#define TEST_HOST            "ftp.ncbi.nlm.nih.gov"
-#define TEST_PORT            0
-#define TEST_USER            "ftp"
-#define TEST_PASS            "none"
-#define TEST_PATH            ((char*) 0)
+#define TEST_HOST "ftp.ncbi.nlm.nih.gov"
+#define TEST_PORT 0
+#define TEST_USER "ftp"
+#define TEST_PASS "none"
+#define TEST_PATH ((char*) 0)
 
 
 int main(int argc, char* argv[])
 {
-    static const char k_chdir[] = "CWD /toolbox/ncbi_tools\n";
-    static const char k_file[] = "RETR CURRENT/ncbi.tar.gz";
-    const char* env = getenv("CONN_DEBUG_PRINTOUT");
-    int/*bool*/ aborting = 0, first;
-    TFCDC_Flags flags = 0;
-    char        buf[1024];
-    CONNECTOR   connector;
-    FILE*       data_file;
-    size_t      size, n;
-    STimeout    timeout;
-    EIO_Status  status;
-    CONN        conn;
+    static const char kChdir[] = "CWD /toolbox/ncbi_tools\n";
+    static const char kFile[] = "RETR CURRENT/ncbi.tar.gz";
+    int/*bool*/   aborting = 0, first;
+    TFCDC_Flags   flag = 0;
+    SConnNetInfo* net_info;
+    char          buf[1024];
+    CONNECTOR     connector;
+    FILE*         data_file;
+    size_t        size, n;
+    EIO_Status    status;
+    CONN          conn;
 
     g_NCBI_ConnectRandomSeed = (int) time(0) ^ NCBI_CONNECT_SRAND_ADDEND;
     srand(g_NCBI_ConnectRandomSeed);
@@ -72,18 +71,16 @@ int main(int argc, char* argv[])
     data_file = fopen("test_ncbi_ftp_connector.out", "wb");
     assert(data_file);
 
-    timeout.sec  = 3;
-    timeout.usec = 0;
-
-    if (env) {
-        if (    strcasecmp(env, "1")    == 0  ||
-                strcasecmp(env, "TRUE") == 0  ||
-                strcasecmp(env, "SOME") == 0)
-            flags |= eFCDC_LogControl;
-        else if (strcasecmp(env, "DATA") == 0)
-            flags |= eFCDC_LogData;
-        else if (strcasecmp(env, "ALL")  == 0)
-            flags |= eFCDC_LogAll;
+    assert((net_info = ConnNetInfo_Create(0)) != 0);
+    if (net_info->debug_printout == eDebugPrintout_Some)
+        flag |= fFCDC_LogControl;
+    else if (net_info->debug_printout == eDebugPrintout_Data)
+        flag |= fFCDC_LogData;
+    else {
+        char val[32];
+        ConnNetInfo_GetValue(0, REG_CONN_DEBUG_PRINTOUT, val, sizeof(val), "");
+        if (strcasecmp(val, "ALL") == 0)
+            flag |= fFCDC_LogAll;
     }
 
     if (TEST_PORT) {
@@ -91,24 +88,22 @@ int main(int argc, char* argv[])
     } else {
         *buf = 0;
     }
-    CORE_LOGF(eLOG_Note, ("Connecting to ftp://%s%s%s@%s%s%s%s",
-                          TEST_USER ? TEST_USER                : "",
-                          TEST_PASS ? ":"                      : "",
-                          TEST_PASS ? TEST_PASS                : "",
-                          TEST_HOST, buf,
-                          !TEST_PATH || *TEST_PATH == '/' ? "" : "/",
-                          TEST_PATH ? TEST_PATH                : ""));
+    CORE_LOGF(eLOG_Note, ("Connecting to ftp://%s:%s@%s%s/",
+                          TEST_USER, TEST_PASS, TEST_HOST, buf));
     /* Run the tests */
     connector = FTP_CreateDownloadConnector(TEST_HOST, TEST_PORT,
                                             TEST_USER, TEST_PASS,
-                                            TEST_PATH, flags);
+                                            TEST_PATH, flag);
 
     if (CONN_Create(connector, &conn) != eIO_Success)
         CORE_LOG(eLOG_Fatal, "Cannot create FTP download connection");
 
-    assert(CONN_SetTimeout(conn, eIO_Open,      &timeout) == eIO_Success);
-    assert(CONN_SetTimeout(conn, eIO_ReadWrite, &timeout) == eIO_Success);
-    assert(CONN_SetTimeout(conn, eIO_Close,     &timeout) == eIO_Success);
+    assert(CONN_SetTimeout(conn, eIO_Open,      net_info->timeout)
+           == eIO_Success);
+    assert(CONN_SetTimeout(conn, eIO_ReadWrite, net_info->timeout)
+           == eIO_Success);
+    assert(CONN_SetTimeout(conn, eIO_Close,     net_info->timeout)
+           == eIO_Success);
 
     if (CONN_Read(conn, buf, sizeof(buf), &n, eIO_ReadPlain) != eIO_Closed)
         CORE_LOG(eLOG_Fatal, "Test failed in empty READ");
@@ -116,7 +111,7 @@ int main(int argc, char* argv[])
     if (CONN_Write(conn, "aaa", 3, &n, eIO_WritePlain) != eIO_Success)
         CORE_LOG(eLOG_Fatal, "Cannot write FTP command");
 
-    if (CONN_Wait(conn, eIO_Read, &timeout) != eIO_Unknown)
+    if (CONN_Wait(conn, eIO_Read, net_info->timeout) != eIO_Unknown)
         CORE_LOG(eLOG_Fatal, "Test failed in waiting on READ");
     CORE_LOG(eLOG_Note, "Unrecognized command was correctly rejected");
 
@@ -156,15 +151,15 @@ int main(int argc, char* argv[])
         printf("<EOF>\n");
     }
 
-    if (CONN_Write(conn, k_chdir, sizeof(k_chdir) - 1, &n, eIO_WritePlain)
+    if (CONN_Write(conn, kChdir, sizeof(kChdir) - 1, &n, eIO_WritePlain)
         != eIO_Success) {
         CORE_LOGF(eLOG_Fatal, ("Cannot execute %.*s",
-                               (int)sizeof(k_chdir) - 2, k_chdir));
+                               (int) sizeof(kChdir) - 2, kChdir));
     }
 
-    if (CONN_Write(conn, k_file, sizeof(k_file) - 1, &n, eIO_WritePersist)
+    if (CONN_Write(conn, kFile, sizeof(kFile) - 1, &n, eIO_WritePersist)
         != eIO_Success) {
-        CORE_LOGF(eLOG_Fatal, ("Cannot write %s", k_file));
+        CORE_LOGF(eLOG_Fatal, ("Cannot write %s", kFile));
     }
 
     size = 0;
@@ -183,10 +178,10 @@ int main(int argc, char* argv[])
     if (!aborting  ||  (rand() & 1) == 0) {
         if (CONN_Write(conn, "NLST blah*", 10, &n, eIO_WritePlain)
             != eIO_Success) {
-            CORE_LOG(eLOG_Fatal, "Cannot write gobbled NLST command");
+            CORE_LOG(eLOG_Fatal, "Cannot write garbled NLST command");
         }
 
-        CORE_LOG(eLOG_Note, "Gobbled NLST command output (should be empty):");
+        CORE_LOG(eLOG_Note, "Garbled NLST command output (should be empty):");
         first = 1/*true*/;
         do {
             status = CONN_Read(conn, buf, sizeof(buf), &n, eIO_ReadPlain);
@@ -214,46 +209,7 @@ int main(int argc, char* argv[])
     }
 
     CORE_LOG(eLOG_Note, "Test completed");
+    ConnNetInfo_Destroy(net_info);
     CORE_SetLOG(0);
     return 0;
 }
-
-
-/*
- * --------------------------------------------------------------------------
- * $Log: test_ncbi_ftp_connector.c,v $
- * Revision 1.11  2005/07/22 16:09:15  lavr
- * Implement data xfer timeout
- *
- * Revision 1.10  2005/07/21 17:38:58  lavr
- * Proper URL printout when connecting
- *
- * Revision 1.9  2005/07/11 18:24:41  lavr
- * Spell ADDEND
- *
- * Revision 1.8  2005/05/20 12:56:35  lavr
- * Added test for multiple commands and '[\r]\n'-terminated input
- *
- * Revision 1.7  2005/05/20 12:11:29  lavr
- * Test ABOR with command and connection closure (both should now work)
- *
- * Revision 1.6  2005/05/20 11:41:47  lavr
- * Separate control and data FTP connection debugging setting
- *
- * Revision 1.5  2005/05/11 20:00:25  lavr
- * Empty NLST result list bug fixed
- *
- * Revision 1.4  2005/05/02 16:13:05  lavr
- * Use global random seed; show NLST use example; add more logging
- *
- * Revision 1.3  2004/12/27 15:32:10  lavr
- * Randomly test ABORTs (if there is an argument for main())
- *
- * Revision 1.2  2004/12/06 22:02:51  ucko
- * +<stdlib.h> for getenv()
- *
- * Revision 1.1  2004/12/06 17:49:00  lavr
- * Initial revision
- *
- * ==========================================================================
- */
