@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   11-29-94
 *
-* $Revision: 6.20 $
+* $Revision: 6.25 $
 *
 * File Description: 
 *
@@ -73,6 +73,9 @@ Boolean LIBCALL VSMFileInit(void)
                            VSMGenericTextAsnOpen, PROC_PRIORITY_DEFAULT);
    
                          /*** SAVE ***/   
+  ObjMgrProcLoad(OMPROC_SAVE, "Save Descriptor File", "Descriptor file", 0,0,0,0,NULL,
+                           VSMDescriptorAsnSave, PROC_PRIORITY_DEFAULT);
+                           
 	ObjMgrProcLoad(OMPROC_SAVE, "Export Protein Feature Table","Protein Feature Table", 0,0,0,0,NULL,
                            VSMExportProteinFeatureTable, PROC_PRIORITY_DEFAULT);
 
@@ -123,6 +126,9 @@ Boolean LIBCALL VSMFileInit(void)
 
 	ObjMgrProcLoad(OMPROC_SAVE, "Export Nucleotide Feature Table","Nucleotide Feature Table", 0,0,0,0,NULL,
                            VSMExportNucFeatureTable, PROC_PRIORITY_DEFAULT);
+
+  ObjMgrProcLoad(OMPROC_SAVE, "Save Entries Within Selected Sets", "ASN.1 text files for each entry in selected sets", 0,0,0,0,NULL,
+                           VSMSaveSetsAsFiles, PROC_PRIORITY_DEFAULT);
                            
 	ObjMgrProcLoad(OMPROC_SAVE, "Save As Sorted FASTA Protein File","Sorted FASTA protein file", 0,0,0,0,NULL,
                            VSMFastaSortedProtSave, PROC_PRIORITY_DEFAULT);
@@ -138,7 +144,7 @@ Boolean LIBCALL VSMFileInit(void)
                            
 	ObjMgrProcLoad(OMPROC_SAVE, "Save As Text ASN1 File","ASN.1 text file", 0,0,0,0,NULL,
                            VSMGenericTextAsnSave, PROC_PRIORITY_DEFAULT);
-                           
+
 	return TRUE;
 }
 
@@ -741,6 +747,7 @@ static void VSMExportFeatureTableBioseqCallback (BioseqPtr bsp, Pointer userdata
   CstType         custom_flags = 0;
   Asn2gbJobPtr    ajp;
   BaseBlockPtr    bbp;
+  XtraBlock       extra;
   Int4            index;
   CharPtr         string;
   
@@ -760,8 +767,9 @@ static void VSMExportFeatureTableBioseqCallback (BioseqPtr bsp, Pointer userdata
   {
     custom_flags |= HIDE_SOURCE_FEATS;
   }
+  MemSet ((Pointer) &extra, 0, sizeof (XtraBlock));
   ajp = asn2gnbk_setup (bsp, NULL, NULL, FTABLE_FMT, DUMP_MODE, NORMAL_STYLE,
-                           0, 0, custom_flags, NULL);
+                           0, 0, custom_flags, &extra);
                            
   if (ftp->export_only_selected 
       && ! BioseqHasSelectedFeatures (ajp, ftp->hide_sources))
@@ -1171,3 +1179,245 @@ Int2 LIBCALLBACK VSMGenericBinAsnSave ( Pointer data )
 }
 
 
+typedef struct setsave {
+  SelStructPtr sel;
+  CharPtr file_base;
+  Int4 file_num;
+} SetSaveData, PNTR SetSavePtr;
+
+static Boolean SaveSetsInOneSelectedSet (GatherObjectPtr gop)
+
+{
+  SetSavePtr      ssp;
+  SelStructPtr    sel;
+  BioseqSetPtr    bssp;
+  CharPtr         filename, file_fmt = "%s_%d.sqn";
+  SeqEntryPtr     sep;
+  AsnIoPtr        aip;
+#ifdef WIN_MAC
+  FILE *fp;
+#endif
+
+  if (gop == NULL || gop->dataptr == NULL || gop->itemtype != OBJ_BIOSEQSET) return TRUE;
+  ssp = (SetSavePtr) gop->userdata;
+  if (ssp == NULL || StringHasNoText (ssp->file_base)) return TRUE;
+
+  sel = ssp->sel;
+  while (sel != NULL 
+         && (sel->entityID != gop->entityID 
+             || sel->itemtype != gop->itemtype 
+             || sel->itemID != gop->itemID))
+  {
+    sel = sel->next;
+  }
+
+  if (sel == NULL) return TRUE;
+
+  bssp = gop->dataptr;
+   
+  filename = (CharPtr) MemNew (sizeof (Char) + (StringLen (ssp->file_base) + StringLen (file_fmt) + 15));
+  for (sep = bssp->seq_set; sep != NULL; sep = sep->next) {
+    sprintf (filename, file_fmt, ssp->file_base, ssp->file_num);
+    ssp->file_num++;
+#ifdef WIN_MAC
+		fp = FileOpen (filename, "r");
+		if (fp != NULL) {
+			FileClose (fp);
+		} else {
+			FileCreate (filename, "TEXT", "ttxt");
+		}
+#endif
+
+		aip = AsnIoOpen(filename, "w");
+		SeqEntryAsnWrite (sep, aip, NULL);
+    AsnIoClose (aip);
+  }
+  filename = MemFree (filename);
+  return TRUE;
+}
+
+
+Int2 LIBCALLBACK VSMSaveSetsAsFiles (Pointer data)
+{
+	Char filename[255];
+	SelStructPtr  ssp, sel;
+  ValNodePtr entity_list = NULL, vnp;
+  SetSaveData ssd;
+  OMProcControlPtr ompcp;
+
+  ompcp = (OMProcControlPtr) data;
+  ssp = ObjMgrGetSelected();
+  if (ssp == NULL)
+	{
+    Message (MSG_ERROR, "Nothing selected!");
+		return OM_MSG_RET_ERROR;
+	}
+
+  /* get file name to use */	
+	filename[0] = '\0';
+	if (GetOutputFileName(filename, (size_t)254, NULL))
+	{
+		WatchCursor();
+    ssd.file_base = filename;
+    ssd.file_num = 1;
+
+    ssd.sel = ssp;
+
+    /* get list of entity IDs */
+	  for (sel = ssp; sel != NULL; sel = sel->next)
+	  {
+      if (sel->itemtype != OBJ_BIOSEQSET) {
+        continue;
+      }
+	    for (vnp = entity_list;
+	        vnp != NULL && vnp->data.intvalue != sel->entityID;
+	        vnp = vnp->next)
+	    {}
+	    if (vnp == NULL)
+	    {
+	      ValNodeAddInt (&entity_list, 0, sel->entityID);
+        GatherObjectsInEntity (sel->entityID, 0, NULL, SaveSetsInOneSelectedSet, (Pointer) &ssd, NULL);
+	    }
+	  }
+	
+
+    ValNodeFree (entity_list);
+		ArrowCursor();
+	}
+	
+	return OM_MSG_RET_DONE;
+}
+
+
+static Boolean AddToSaveList (GatherContextPtr gcp)
+
+{
+  ValNodePtr PNTR list;
+
+  list = (ValNodePtr PNTR) gcp->userdata;
+  if (list == NULL) return TRUE;
+  ValNodeAddPointer (list, gcp->thistype, gcp->thisitem);
+  return TRUE;
+}
+
+
+typedef struct savesetsdp {
+  AsnIoPtr aip;
+  Boolean  already_have_molinfo;  
+} SaveSetSdpData, PNTR SaveSetSdpPtr;
+
+
+static void SaveSetDescriptors (SeqDescrPtr sdp, Pointer userdata)
+{
+  SaveSetSdpPtr sp;
+  MolInfoPtr    mip;
+
+  if (sdp == NULL || userdata == NULL) return;
+  if (sdp->choice != Seq_descr_source
+      && sdp->choice != Seq_descr_pub
+      && sdp->choice != Seq_descr_molinfo
+      && sdp->choice != Seq_descr_comment) return;
+
+  sp = (SaveSetSdpPtr) userdata;
+  if (sdp->choice == Seq_descr_molinfo
+      && (mip = (MolInfoPtr) sdp->data.ptrvalue) != NULL)
+  {
+    if (mip->biomol == MOLECULE_TYPE_PEPTIDE || sp->already_have_molinfo) 
+    {
+      return;
+    }
+    else
+    {
+      sp->already_have_molinfo = TRUE;
+    }
+  }
+  SeqDescAsnWrite (sdp, sp->aip, NULL);
+  AsnPrintNewLine (sp->aip);
+  AsnIoFlush (sp->aip);
+}
+
+Int2 LIBCALLBACK VSMDescriptorAsnSave (Pointer data)
+{
+  OMProcControlPtr ompcp;
+  Char filename[255];
+  SelStructPtr  ssp, sel;
+  SeqDescrPtr   sdp;
+  BioseqPtr     bsp;
+  SeqEntryPtr   sep;
+  SeqMgrDescContext dcontext;
+#ifdef WIN_MAC
+  FILE * fp;
+#endif
+  ValNodePtr vnp;
+  SaveSetSdpData sd;
+  ValNodePtr obj_list = NULL;
+
+  ompcp = (OMProcControlPtr)data;
+  if (ompcp == NULL) return OM_MSG_RET_ERROR;
+
+  sd.already_have_molinfo = FALSE;
+  ssp = ObjMgrGetSelected();
+  if (ssp == NULL)
+	{
+    Message (MSG_ERROR, "You must select a sequence or set from which descriptors should be saved");
+    return OM_MSG_RET_DONE;
+  } else {
+	  for (sel = ssp; sel != NULL; sel = sel->next)
+	  {
+      GatherItem (sel->entityID, sel->itemID, sel->itemtype,
+                (Pointer) &obj_list, AddToSaveList);
+    }
+  }
+
+  /* get file name to use */	
+	filename[0] = '\0';
+	if (GetOutputFileName(filename, (size_t)254, NULL))
+	{
+		WatchCursor();
+#ifdef WIN_MAC
+		fp = FileOpen (filename, "r");
+		if (fp != NULL) {
+			FileClose (fp);
+		} else {
+			FileCreate (filename, "TEXT", "ttxt");
+		}
+#endif
+
+		sd.aip = AsnIoOpen(filename, "w");
+	  for (vnp = obj_list; vnp != NULL; vnp = vnp->next)
+	  {
+      switch (vnp->choice) {
+        case OBJ_SEQDESC:
+          sdp = (SeqDescrPtr) vnp->data.ptrvalue;
+          SeqDescAsnWrite (sdp, sd.aip, NULL);
+          AsnPrintNewLine (sd.aip);
+          AsnIoFlush (sd.aip);
+          break;
+        case OBJ_BIOSEQ:
+          bsp = (BioseqPtr) vnp->data.ptrvalue;
+          for (sdp = SeqMgrGetNextDescriptor (bsp, NULL, 0, &dcontext);
+               sdp != NULL;
+               sdp = SeqMgrGetNextDescriptor (bsp, sdp, 0, &dcontext)) {
+            if (sdp->choice != Seq_descr_source
+                && sdp->choice != Seq_descr_pub
+                && sdp->choice != Seq_descr_molinfo
+                && sdp->choice != Seq_descr_comment) continue;
+            SeqDescAsnWrite (sdp, sd.aip, NULL);
+            AsnPrintNewLine (sd.aip);
+            AsnIoFlush (sd.aip);
+          }
+          break;
+        case OBJ_BIOSEQSET:
+          sep = SeqMgrGetSeqEntryForData (vnp->data.ptrvalue);
+          VisitDescriptorsInSep (sep, &sd, SaveSetDescriptors);
+          break;
+      }              
+    }   
+		AsnIoClose(sd.aip);
+		ArrowCursor();
+	}
+	
+	return OM_MSG_RET_DONE;  
+}
+
+
