@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   11-29-94
 *
-* $Revision: 6.6 $
+* $Revision: 6.8 $
 *
 * File Description: 
 *
@@ -76,6 +76,7 @@ Int2 LIBCALLBACK VSMGenericTextAsnSave PROTO((Pointer data));
 Int2 LIBCALLBACK VSMGenericBinAsnSave PROTO((Pointer data));
 Int2 LIBCALLBACK VSMFastaProtSave PROTO((Pointer data));
 Int2 LIBCALLBACK VSMFastaNucSave PROTO((Pointer data));
+Int2 LIBCALLBACK VSMSaveSetsAsFiles PROTO((Pointer data));
 Int2 LIBCALLBACK VSMExportNucFeatureTable ( Pointer data );
 Int2 LIBCALLBACK VSMExportNucFeatureTableSuppressProteinIDs ( Pointer data );
 Int2 LIBCALLBACK VSMExportNucFeatureTableWithoutSources ( Pointer data );
@@ -84,6 +85,7 @@ Int2 LIBCALLBACK VSMExportNucFeatureTableSelectedFeatures (Pointer data);
 Int2 LIBCALLBACK VSMExportNucFeatureTableSelectedFeaturesSuppressProteinIDs (Pointer data);
 Int2 LIBCALLBACK VSMExportProteinFeatureTable (Pointer data);
 Int2 LIBCALLBACK VSMFastaSortedProtSave (Pointer data);
+Int2 LIBCALLBACK VSMDescriptorAsnSave (Pointer data);
 NLM_EXTERN void ViewSortedProteins (SeqEntryPtr sep);
 
 extern void ExportSeqAnnotFeatureTable (FILE *fp, SeqAnnotPtr sap);
