@@ -32,8 +32,14 @@ Contents: definitions and prototypes used by blastkar.c to calculate BLAST
 
 ******************************************************************************/
 
-/* $Revision: 6.39 $ 
+/* $Revision: 6.41 $ 
 * $Log: blastkar.h,v $
+* Revision 6.41  2005/10/06 12:49:39  madden
+* Add prototypes for BlastKarlinGetNuclAlphaBeta and BlastKarlinBlkNuclGappedCalc
+*
+* Revision 6.40  2005/07/27 17:48:57  coulouri
+* remove hardcoded paths
+*
 * Revision 6.39  2004/09/28 16:04:19  papadopo
 * From Michael Gertz:
 * 1. Pass the effective database size into BlastSmallGapSumE,
@@ -317,10 +323,6 @@ of K, so high accuracy is generally unwarranted.
 #define BLAST_KARLIN_K_ITER_MAX 100
 #define BLAST_SUMP_EPSILON_DEFAULT 0.002 /* accuracy for SumP calculations */
 
-/* 
-	Where are the BLAST matrices located?
-*/
-#define BLASTMAT_DIR "/usr/ncbi/blast/matrix"
 /*
 	Maps the ncbi4na alphabet to blastna, an alphabet that blastn uses
 	as the first four characters have the same representation as in
@@ -438,6 +440,7 @@ protein alphabet (e.g., ncbistdaa etc.), FALSE for nt. alphabets. */
 	Int4	effective_query_length; /* shortened query length. */
 	Int8	effective_db_length;	/* trimmed db length */
 	Int8	effective_search_sp;	/* product of above two */
+        Boolean round_down; /* round down to next even score if the score is odd. */
 	} BLAST_ScoreBlk, PNTR BLAST_ScoreBlkPtr;
 
 /* Used for communicating between BLAST and other applications. */
@@ -636,6 +639,17 @@ Int2 LIBCALL BlastKarlinGetDefaultMatrixValues PROTO((CharPtr matrix, Int4Ptr op
 Int4Ptr PNTR LIBCALL BlastMatrixToTxMatrix PROTO((BLAST_MatrixPtr matrix));
 Int4Ptr PNTR LIBCALL TxMatrixDestruct PROTO((Int4Ptr PNTR txmatrix)); 
 
+Int2 BlastKarlinGetNuclAlphaBeta PROTO((Int4 reward, Int4 penalty, Int4 gap_open,
+                            Int4 gap_extend, BLAST_KarlinBlkPtr kbp,
+                            Boolean gapped_calculation,
+                            double *alpha, double *beta));
+
+Int2 BlastKarlinBlkNuclGappedCalc PROTO((BLAST_KarlinBlk* kbp, Int4 gap_open,
+                              Int4 gap_extend, Int4 reward, Int4 penalty,
+                              BLAST_KarlinBlk* kbp_ungap,
+                              Boolean* round_down,
+                              ValNodePtr* error_return));
+
 Int4
 BlastComputeLengthAdjustment(Nlm_FloatHi K,
                                   Nlm_FloatHi logK,
